@@ -2,10 +2,10 @@
  *
  * Project:  CTG driver
  * Purpose:  GDALDataset driver for CTG dataset.
- * Author:   Even Rouault, <even dot rouault at mines dash paris dot org>
+ * Author:   Even Rouault, <even dot rouault at spatialys.com>
  *
  ******************************************************************************
- * Copyright (c) 2011, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2011, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -30,75 +30,69 @@
 #include "gdal_pam.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: ctgdataset.cpp c110ff1ae189c96166f9d82a9d7873a265806d59 2018-04-29 23:11:43 +0200 Even Rouault $")
-
 constexpr int HEADER_LINE_COUNT = 5;
 
 typedef struct
 {
     int nCode;
-    const char* pszDesc;
+    const char *pszDesc;
 } LULCDescStruct;
 
-static const LULCDescStruct asLULCDesc[] =
-{
-    {1, "Urban or Built-Up Land" },
-    {2, "Agricultural Land" },
-    {3, "Rangeland" },
-    {4, "Forest Land" },
-    {5, "Water" },
-    {6, "Wetland" },
-    {7, "Barren Land" },
-    {8, "Tundra" },
-    {9, "Perennial Snow and Ice" },
-    {11, "Residential" },
-    {12, "Commercial Services" },
-    {13, "Industrial" },
-    {14, "Transportation, Communications" },
-    {15, "Industrial and Commercial" },
-    {16, "Mixed Urban or Built-Up Land" },
-    {17, "Other Urban or Built-Up Land" },
-    {21, "Cropland and Pasture" },
-    {22, "Orchards, Groves, Vineyards, Nurseries" },
-    {23, "Confined Feeding Operations" },
-    {24, "Other Agricultural Land" },
-    {31, "Herbaceous Rangeland" },
-    {32, "Shrub and Brush Rangeland" },
-    {33, "Mixed Rangeland" },
-    {41, "Deciduous Forest Land" },
-    {42, "Evergreen Forest Land" },
-    {43, "Mixed Forest Land" },
-    {51, "Streams and Canals" },
-    {52, "Lakes" },
-    {53, "Reservoirs" },
-    {54, "Bays and Estuaries" },
-    {61, "Forested Wetlands" },
-    {62, "Nonforested Wetlands" },
-    {71, "Dry Salt Flats" },
-    {72, "Beaches" },
-    {73, "Sandy Areas Other than Beaches" },
-    {74, "Bare Exposed Rock" },
-    {75, "Strip Mines, Quarries, and Gravel Pits" },
-    {76, "Transitional Areas" },
-    {77, "Mixed Barren Land" },
-    {81, "Shrub and Brush Tundra" },
-    {82, "Herbaceous Tundra" },
-    {83, "Bare Ground" },
-    {84, "Wet Tundra" },
-    {85, "Mixed Tundra" },
-    {91, "Perennial Snowfields" },
-    {92, "Glaciers" }
-};
+static const LULCDescStruct asLULCDesc[] = {
+    {1, "Urban or Built-Up Land"},
+    {2, "Agricultural Land"},
+    {3, "Rangeland"},
+    {4, "Forest Land"},
+    {5, "Water"},
+    {6, "Wetland"},
+    {7, "Barren Land"},
+    {8, "Tundra"},
+    {9, "Perennial Snow and Ice"},
+    {11, "Residential"},
+    {12, "Commercial Services"},
+    {13, "Industrial"},
+    {14, "Transportation, Communications"},
+    {15, "Industrial and Commercial"},
+    {16, "Mixed Urban or Built-Up Land"},
+    {17, "Other Urban or Built-Up Land"},
+    {21, "Cropland and Pasture"},
+    {22, "Orchards, Groves, Vineyards, Nurseries"},
+    {23, "Confined Feeding Operations"},
+    {24, "Other Agricultural Land"},
+    {31, "Herbaceous Rangeland"},
+    {32, "Shrub and Brush Rangeland"},
+    {33, "Mixed Rangeland"},
+    {41, "Deciduous Forest Land"},
+    {42, "Evergreen Forest Land"},
+    {43, "Mixed Forest Land"},
+    {51, "Streams and Canals"},
+    {52, "Lakes"},
+    {53, "Reservoirs"},
+    {54, "Bays and Estuaries"},
+    {61, "Forested Wetlands"},
+    {62, "Nonforested Wetlands"},
+    {71, "Dry Salt Flats"},
+    {72, "Beaches"},
+    {73, "Sandy Areas Other than Beaches"},
+    {74, "Bare Exposed Rock"},
+    {75, "Strip Mines, Quarries, and Gravel Pits"},
+    {76, "Transitional Areas"},
+    {77, "Mixed Barren Land"},
+    {81, "Shrub and Brush Tundra"},
+    {82, "Herbaceous Tundra"},
+    {83, "Bare Ground"},
+    {84, "Wet Tundra"},
+    {85, "Mixed Tundra"},
+    {91, "Perennial Snowfields"},
+    {92, "Glaciers"}};
 
-static const char* const apszBandDescription[] =
-{
+static const char *const apszBandDescription[] = {
     "Land Use and Land Cover",
     "Political units",
     "Census county subdivisions and SMSA tracts",
     "Hydrologic units",
     "Federal land ownership",
-    "State land ownership"
-};
+    "State land ownership"};
 
 /************************************************************************/
 /* ==================================================================== */
@@ -108,32 +102,35 @@ static const char* const apszBandDescription[] =
 
 class CTGRasterBand;
 
-class CTGDataset : public GDALPamDataset
+class CTGDataset final : public GDALPamDataset
 {
     friend class CTGRasterBand;
 
-    VSILFILE   *fp;
+    VSILFILE *fp;
 
-    int         nNWEasting, nNWNorthing, nCellSize, nUTMZone;
-    char       *pszProjection;
+    int nNWEasting, nNWNorthing, nCellSize, nUTMZone;
+    OGRSpatialReference m_oSRS{};
 
-    int         bHasReadImagery;
-    GByte      *pabyImage;
+    int bHasReadImagery;
+    GByte *pabyImage;
 
-    int         ReadImagery();
+    int ReadImagery();
 
-    static const char* ExtractField(char* szOutput, const char* pszBuffer,
-                                       int nOffset, int nLength);
+    static const char *ExtractField(char *szOutput, const char *pszBuffer,
+                                    int nOffset, int nLength);
 
   public:
     CTGDataset();
     ~CTGDataset() override;
 
-    CPLErr GetGeoTransform( double * ) override;
-    const char* GetProjectionRef() override;
+    CPLErr GetGeoTransform(double *) override;
+    const OGRSpatialReference *GetSpatialRef() const override
+    {
+        return &m_oSRS;
+    }
 
-    static GDALDataset *Open( GDALOpenInfo * );
-    static int          Identify( GDALOpenInfo * );
+    static GDALDataset *Open(GDALOpenInfo *);
+    static int Identify(GDALOpenInfo *);
 };
 
 /************************************************************************/
@@ -142,19 +139,18 @@ class CTGDataset : public GDALPamDataset
 /* ==================================================================== */
 /************************************************************************/
 
-class CTGRasterBand : public GDALPamRasterBand
+class CTGRasterBand final : public GDALPamRasterBand
 {
     friend class CTGDataset;
 
-    char** papszCategories;
+    char **papszCategories;
 
   public:
-
-    CTGRasterBand( CTGDataset *, int );
+    CTGRasterBand(CTGDataset *, int);
     ~CTGRasterBand() override;
 
-    CPLErr IReadBlock( int, int, void * ) override;
-    double GetNoDataValue( int *pbSuccess = nullptr ) override;
+    CPLErr IReadBlock(int, int, void *) override;
+    double GetNoDataValue(int *pbSuccess = nullptr) override;
     char **GetCategoryNames() override;
 };
 
@@ -162,8 +158,8 @@ class CTGRasterBand : public GDALPamRasterBand
 /*                           CTGRasterBand()                            */
 /************************************************************************/
 
-CTGRasterBand::CTGRasterBand( CTGDataset *poDSIn, int nBandIn ) :
-    papszCategories(nullptr)
+CTGRasterBand::CTGRasterBand(CTGDataset *poDSIn, int nBandIn)
+    : papszCategories(nullptr)
 {
     poDS = poDSIn;
     nBand = nBandIn;
@@ -187,15 +183,15 @@ CTGRasterBand::~CTGRasterBand()
 /*                             IReadBlock()                             */
 /************************************************************************/
 
-CPLErr CTGRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
-                                  CPL_UNUSED int nBlockYOff,
-                                  void * pImage )
+CPLErr CTGRasterBand::IReadBlock(CPL_UNUSED int nBlockXOff,
+                                 CPL_UNUSED int nBlockYOff, void *pImage)
 {
-    CTGDataset* poGDS = (CTGDataset* ) poDS;
+    CTGDataset *poGDS = (CTGDataset *)poDS;
 
     poGDS->ReadImagery();
     memcpy(pImage,
-           poGDS->pabyImage + (nBand - 1) * nBlockXSize * nBlockYSize * sizeof(int),
+           poGDS->pabyImage +
+               (nBand - 1) * nBlockXSize * nBlockYSize * sizeof(int),
            nBlockXSize * nBlockYSize * sizeof(int));
 
     return CE_None;
@@ -205,7 +201,7 @@ CPLErr CTGRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
 /*                           GetNoDataValue()                           */
 /************************************************************************/
 
-double CTGRasterBand::GetNoDataValue( int *pbSuccess )
+double CTGRasterBand::GetNoDataValue(int *pbSuccess)
 {
     if (pbSuccess)
         *pbSuccess = TRUE;
@@ -227,12 +223,12 @@ char **CTGRasterBand::GetCategoryNames()
 
     int nasLULCDescSize = (int)(sizeof(asLULCDesc) / sizeof(asLULCDesc[0]));
     int nCategoriesSize = asLULCDesc[nasLULCDescSize - 1].nCode;
-    papszCategories = (char**)CPLCalloc(nCategoriesSize + 2, sizeof(char*));
-    for(int i=0;i<nasLULCDescSize;i++)
+    papszCategories = (char **)CPLCalloc(nCategoriesSize + 2, sizeof(char *));
+    for (int i = 0; i < nasLULCDescSize; i++)
     {
         papszCategories[asLULCDesc[i].nCode] = CPLStrdup(asLULCDesc[i].pszDesc);
     }
-    for(int i=0;i<nCategoriesSize;i++)
+    for (int i = 0; i < nCategoriesSize; i++)
     {
         if (papszCategories[i] == nullptr)
             papszCategories[i] = CPLStrdup("");
@@ -246,16 +242,12 @@ char **CTGRasterBand::GetCategoryNames()
 /*                            ~CTGDataset()                            */
 /************************************************************************/
 
-CTGDataset::CTGDataset() :
-    fp(nullptr),
-    nNWEasting(0),
-    nNWNorthing(0),
-    nCellSize(0),
-    nUTMZone(0),
-    pszProjection(nullptr),
-    bHasReadImagery(FALSE),
-    pabyImage(nullptr)
-{}
+CTGDataset::CTGDataset()
+    : fp(nullptr), nNWEasting(0), nNWNorthing(0), nCellSize(0), nUTMZone(0),
+      bHasReadImagery(FALSE), pabyImage(nullptr)
+{
+    m_oSRS.SetAxisMappingStrategy(OAMS_TRADITIONAL_GIS_ORDER);
+}
 
 /************************************************************************/
 /*                            ~CTGDataset()                            */
@@ -264,9 +256,8 @@ CTGDataset::CTGDataset() :
 CTGDataset::~CTGDataset()
 
 {
-    CPLFree(pszProjection);
     CPLFree(pabyImage);
-    if( fp != nullptr )
+    if (fp != nullptr)
         VSIFCloseL(fp);
 }
 
@@ -274,7 +265,7 @@ CTGDataset::~CTGDataset()
 /*                              ExtractField()                          */
 /************************************************************************/
 
-const char* CTGDataset::ExtractField(char* szField, const char* pszBuffer,
+const char *CTGDataset::ExtractField(char *szField, const char *pszBuffer,
                                      int nOffset, int nLength)
 {
     CPLAssert(nLength <= 10);
@@ -300,7 +291,7 @@ int CTGDataset::ReadImagery()
     int nLine = HEADER_LINE_COUNT;
     VSIFSeekL(fp, nLine * 80, SEEK_SET);
     int nCells = nRasterXSize * nRasterYSize;
-    while(VSIFReadL(szLine, 1, 80, fp) == 80)
+    while (VSIFReadL(szLine, 1, 80, fp) == 80)
     {
         int nZone = atoi(ExtractField(szField, szLine, 0, 3));
         if (nZone != nUTMZone)
@@ -314,8 +305,8 @@ int CTGDataset::ReadImagery()
         int nY = atoi(ExtractField(szField, szLine, 11, 8)) + nCellSize / 2;
         GIntBig nDiffX = static_cast<GIntBig>(nX) - nNWEasting;
         GIntBig nDiffY = static_cast<GIntBig>(nNWNorthing) - nY;
-        if (nDiffX < 0 || (nDiffX % nCellSize) != 0 ||
-            nDiffY < 0 || (nDiffY % nCellSize) != 0)
+        if (nDiffX < 0 || (nDiffX % nCellSize) != 0 || nDiffY < 0 ||
+            (nDiffY % nCellSize) != 0)
         {
             CPLError(CE_Failure, CPLE_AppDefined,
                      "Read error at line %d, %s. Unexpected cell coordinates",
@@ -331,15 +322,16 @@ int CTGDataset::ReadImagery()
                      nLine, szLine);
             return FALSE;
         }
-        for(int i=0;i<6;i++)
+        for (int i = 0; i < 6; i++)
         {
-            int nVal = atoi(ExtractField(szField, szLine, 20 + 10*i, 10));
+            int nVal = atoi(ExtractField(szField, szLine, 20 + 10 * i, 10));
             if (nVal >= 2000000000)
                 nVal = 0;
-            ((int*)pabyImage)[i * nCells + nCellY * nRasterXSize + nCellX] = nVal;
+            ((int *)pabyImage)[i * nCells + nCellY * nRasterXSize + nCellX] =
+                nVal;
         }
 
-        nLine ++;
+        nLine++;
     }
 
     return TRUE;
@@ -349,14 +341,14 @@ int CTGDataset::ReadImagery()
 /*                             Identify()                               */
 /************************************************************************/
 
-int CTGDataset::Identify( GDALOpenInfo * poOpenInfo )
+int CTGDataset::Identify(GDALOpenInfo *poOpenInfo)
 {
-    CPLString osFilename(poOpenInfo->pszFilename);
+    CPLString osFilename;  // let in that scope
 
-    GDALOpenInfo* poOpenInfoToDelete = nullptr;
+    GDALOpenInfo *poOpenInfoToDelete = nullptr;
     /*  GZipped grid_cell.gz files are common, so automagically open them */
     /*  if the /vsigzip/ has not been explicitly passed */
-    const char* pszFilename = CPLGetFilename(poOpenInfo->pszFilename);
+    const char *pszFilename = CPLGetFilename(poOpenInfo->pszFilename);
     if ((EQUAL(pszFilename, "grid_cell.gz") ||
          EQUAL(pszFilename, "grid_cell1.gz") ||
          EQUAL(pszFilename, "grid_cell2.gz")) &&
@@ -364,9 +356,8 @@ int CTGDataset::Identify( GDALOpenInfo * poOpenInfo )
     {
         osFilename = "/vsigzip/";
         osFilename += poOpenInfo->pszFilename;
-        poOpenInfo = poOpenInfoToDelete =
-                new GDALOpenInfo(osFilename.c_str(), GA_ReadOnly,
-                                 poOpenInfo->GetSiblingFiles());
+        poOpenInfo = poOpenInfoToDelete = new GDALOpenInfo(
+            osFilename.c_str(), GA_ReadOnly, poOpenInfo->GetSiblingFiles());
     }
 
     if (poOpenInfo->nHeaderBytes < HEADER_LINE_COUNT * 80)
@@ -375,14 +366,14 @@ int CTGDataset::Identify( GDALOpenInfo * poOpenInfo )
         return FALSE;
     }
 
-/* -------------------------------------------------------------------- */
-/*      Chech that it looks roughly as a CTG dataset                    */
-/* -------------------------------------------------------------------- */
-    const char* pszData = (const char*)poOpenInfo->pabyHeader;
-    for(int i=0;i<4 * 80;i++)
+    /* -------------------------------------------------------------------- */
+    /*      Check that it looks roughly as a CTG dataset                    */
+    /* -------------------------------------------------------------------- */
+    const char *pszData = (const char *)poOpenInfo->pabyHeader;
+    for (int i = 0; i < 4 * 80; i++)
     {
-        if (!((pszData[i] >= '0' && pszData[i] <= '9') ||
-              pszData[i] == ' ' || pszData[i] == '-'))
+        if (!((pszData[i] >= '0' && pszData[i] <= '9') || pszData[i] == ' ' ||
+              pszData[i] == '-'))
         {
             delete poOpenInfoToDelete;
             return FALSE;
@@ -392,13 +383,12 @@ int CTGDataset::Identify( GDALOpenInfo * poOpenInfo )
     char szField[11];
     int nRows = atoi(ExtractField(szField, pszData, 0, 10));
     int nCols = atoi(ExtractField(szField, pszData, 20, 10));
-    int nMinColIndex = atoi(ExtractField(szField, pszData+80, 0, 5));
-    int nMinRowIndex = atoi(ExtractField(szField, pszData+80, 5, 5));
-    int nMaxColIndex = atoi(ExtractField(szField, pszData+80, 10, 5));
-    int nMaxRowIndex = atoi(ExtractField(szField, pszData+80, 15, 5));
+    int nMinColIndex = atoi(ExtractField(szField, pszData + 80, 0, 5));
+    int nMinRowIndex = atoi(ExtractField(szField, pszData + 80, 5, 5));
+    int nMaxColIndex = atoi(ExtractField(szField, pszData + 80, 10, 5));
+    int nMaxRowIndex = atoi(ExtractField(szField, pszData + 80, 15, 5));
 
-    if (nRows <= 0 || nCols <= 0 ||
-        nMinColIndex != 1 || nMinRowIndex != 1 ||
+    if (nRows <= 0 || nCols <= 0 || nMinColIndex != 1 || nMinRowIndex != 1 ||
         nMaxRowIndex != nRows || nMaxColIndex != nCols)
     {
         delete poOpenInfoToDelete;
@@ -413,7 +403,7 @@ int CTGDataset::Identify( GDALOpenInfo * poOpenInfo )
 /*                                Open()                                */
 /************************************************************************/
 
-GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
+GDALDataset *CTGDataset::Open(GDALOpenInfo *poOpenInfo)
 
 {
     if (!Identify(poOpenInfo))
@@ -423,7 +413,7 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
 
     /*  GZipped grid_cell.gz files are common, so automagically open them */
     /*  if the /vsigzip/ has not been explicitly passed */
-    const char* pszFilename = CPLGetFilename(poOpenInfo->pszFilename);
+    const char *pszFilename = CPLGetFilename(poOpenInfo->pszFilename);
     if ((EQUAL(pszFilename, "grid_cell.gz") ||
          EQUAL(pszFilename, "grid_cell1.gz") ||
          EQUAL(pszFilename, "grid_cell2.gz")) &&
@@ -435,28 +425,29 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
 
     if (poOpenInfo->eAccess == GA_Update)
     {
-        CPLError( CE_Failure, CPLE_NotSupported,
-                  "The CTG driver does not support update access to existing"
-                  " datasets.\n" );
+        CPLError(CE_Failure, CPLE_NotSupported,
+                 "The CTG driver does not support update access to existing"
+                 " datasets.\n");
         return nullptr;
     }
 
-/* -------------------------------------------------------------------- */
-/*      Find dataset characteristics                                    */
-/* -------------------------------------------------------------------- */
-    VSILFILE* fp = VSIFOpenL(osFilename.c_str(), "rb");
+    /* -------------------------------------------------------------------- */
+    /*      Find dataset characteristics                                    */
+    /* -------------------------------------------------------------------- */
+    VSILFILE *fp = VSIFOpenL(osFilename.c_str(), "rb");
     if (fp == nullptr)
         return nullptr;
 
-    char szHeader[HEADER_LINE_COUNT * 80+1];
+    char szHeader[HEADER_LINE_COUNT * 80 + 1];
     szHeader[HEADER_LINE_COUNT * 80] = 0;
-    if (VSIFReadL(szHeader, 1, HEADER_LINE_COUNT * 80, fp) != HEADER_LINE_COUNT * 80)
+    if (VSIFReadL(szHeader, 1, HEADER_LINE_COUNT * 80, fp) !=
+        HEADER_LINE_COUNT * 80)
     {
         VSIFCloseL(fp);
         return nullptr;
     }
 
-    for(int i=HEADER_LINE_COUNT * 80 - 1;i>=0;i--)
+    for (int i = HEADER_LINE_COUNT * 80 - 1; i >= 0; i--)
     {
         if (szHeader[i] == ' ')
             szHeader[i] = 0;
@@ -468,9 +459,9 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
     int nRows = atoi(ExtractField(szField, szHeader, 0, 10));
     int nCols = atoi(ExtractField(szField, szHeader, 20, 10));
 
-/* -------------------------------------------------------------------- */
-/*      Create a corresponding GDALDataset.                             */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Create a corresponding GDALDataset.                             */
+    /* -------------------------------------------------------------------- */
     CTGDataset *poDS = new CTGDataset();
     poDS->fp = fp;
     fp = nullptr;
@@ -485,8 +476,8 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
         delete poDS;
         return nullptr;
     }
-    poDS->nNWEasting = atoi(ExtractField(szField, szHeader + 3*80, 40, 10));
-    poDS->nNWNorthing = atoi(ExtractField(szField, szHeader + 3*80, 50, 10));
+    poDS->nNWEasting = atoi(ExtractField(szField, szHeader + 3 * 80, 40, 10));
+    poDS->nNWNorthing = atoi(ExtractField(szField, szHeader + 3 * 80, 50, 10));
     poDS->nUTMZone = atoi(ExtractField(szField, szHeader, 50, 5));
     if (poDS->nUTMZone <= 0 || poDS->nUTMZone > 60)
     {
@@ -494,9 +485,7 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
         return nullptr;
     }
 
-    OGRSpatialReference oSRS;
-    oSRS.importFromEPSG(32600 + poDS->nUTMZone);
-    oSRS.exportToWkt(&poDS->pszProjection);
+    poDS->m_oSRS.importFromEPSG(32600 + poDS->nUTMZone);
 
     if (!GDALCheckDatasetDimensions(poDS->nRasterXSize, poDS->nRasterYSize))
     {
@@ -504,10 +493,10 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
         return nullptr;
     }
 
-/* -------------------------------------------------------------------- */
-/*      Read the imagery                                                */
-/* -------------------------------------------------------------------- */
-    GByte* pabyImage = (GByte*)VSICalloc(nCols * nRows, 6 * sizeof(int));
+    /* -------------------------------------------------------------------- */
+    /*      Read the imagery                                                */
+    /* -------------------------------------------------------------------- */
+    GByte *pabyImage = (GByte *)VSICalloc(nCols * nRows, 6 * sizeof(int));
     if (pabyImage == nullptr)
     {
         delete poDS;
@@ -515,26 +504,26 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
     }
     poDS->pabyImage = pabyImage;
 
-/* -------------------------------------------------------------------- */
-/*      Create band information objects.                                */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Create band information objects.                                */
+    /* -------------------------------------------------------------------- */
     poDS->nBands = 6;
-    for( int i = 0; i < poDS->nBands; i++ )
+    for (int i = 0; i < poDS->nBands; i++)
     {
-        poDS->SetBand( i+1, new CTGRasterBand( poDS, i+1 ) );
-        poDS->GetRasterBand(i+1)->SetDescription(apszBandDescription[i]);
+        poDS->SetBand(i + 1, new CTGRasterBand(poDS, i + 1));
+        poDS->GetRasterBand(i + 1)->SetDescription(apszBandDescription[i]);
     }
 
-/* -------------------------------------------------------------------- */
-/*      Initialize any PAM information.                                 */
-/* -------------------------------------------------------------------- */
-    poDS->SetDescription( poOpenInfo->pszFilename );
+    /* -------------------------------------------------------------------- */
+    /*      Initialize any PAM information.                                 */
+    /* -------------------------------------------------------------------- */
+    poDS->SetDescription(poOpenInfo->pszFilename);
     poDS->TryLoadXML();
 
-/* -------------------------------------------------------------------- */
-/*      Support overviews.                                              */
-/* -------------------------------------------------------------------- */
-    poDS->oOvManager.Initialize( poDS, poOpenInfo->pszFilename );
+    /* -------------------------------------------------------------------- */
+    /*      Support overviews.                                              */
+    /* -------------------------------------------------------------------- */
+    poDS->oOvManager.Initialize(poDS, poOpenInfo->pszFilename);
 
     return poDS;
 }
@@ -543,7 +532,7 @@ GDALDataset *CTGDataset::Open( GDALOpenInfo * poOpenInfo )
 /*                          GetGeoTransform()                           */
 /************************************************************************/
 
-CPLErr CTGDataset::GetGeoTransform( double * padfTransform )
+CPLErr CTGDataset::GetGeoTransform(double *padfTransform)
 
 {
     padfTransform[0] = static_cast<double>(nNWEasting) - nCellSize / 2;
@@ -556,16 +545,6 @@ CPLErr CTGDataset::GetGeoTransform( double * padfTransform )
     return CE_None;
 }
 
-/************************************************************************/
-/*                         GetProjectionRef()                           */
-/************************************************************************/
-
-const char* CTGDataset::GetProjectionRef()
-
-{
-    return pszProjection;
-}
-
 /************************************************************************/
 /*                         GDALRegister_CTG()                           */
 /************************************************************************/
@@ -573,22 +552,21 @@ const char* CTGDataset::GetProjectionRef()
 void GDALRegister_CTG()
 
 {
-    if( GDALGetDriverByName( "CTG" ) != nullptr )
-      return;
+    if (GDALGetDriverByName("CTG") != nullptr)
+        return;
 
     GDALDriver *poDriver = new GDALDriver();
 
-    poDriver->SetDescription( "CTG" );
-    poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
-    poDriver->SetMetadataItem( GDAL_DMD_LONGNAME,
-                               "USGS LULC Composite Theme Grid" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC,
-                               "frmt_various.html#CTG" );
+    poDriver->SetDescription("CTG");
+    poDriver->SetMetadataItem(GDAL_DCAP_RASTER, "YES");
+    poDriver->SetMetadataItem(GDAL_DMD_LONGNAME,
+                              "USGS LULC Composite Theme Grid");
+    poDriver->SetMetadataItem(GDAL_DMD_HELPTOPIC, "drivers/raster/ctg.html");
 
-    poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
+    poDriver->SetMetadataItem(GDAL_DCAP_VIRTUALIO, "YES");
 
     poDriver->pfnOpen = CTGDataset::Open;
     poDriver->pfnIdentify = CTGDataset::Identify;
 
-    GetGDALDriverManager()->RegisterDriver( poDriver );
+    GetGDALDriverManager()->RegisterDriver(poDriver);
 }
