@@ -62,7 +62,7 @@
 #include <algorithm>
 
 #ifdef _MSC_VER
-#  pragma warning(disable:4611)
+#pragma warning(disable : 4611)
 #endif
 
 /************************************************************************/
@@ -74,111 +74,110 @@
 class PNGRasterBand;
 
 #ifdef _MSC_VER
-#pragma warning( push )
+#pragma warning(push)
 // 'PNGDataset': structure was padded due to __declspec(align()) at line where
 // we use `jmp_buf`.
-#pragma warning( disable : 4324 )
+#pragma warning(disable : 4324)
 #endif
 
-class PNGDataset final: public GDALPamDataset
+class PNGDataset final : public GDALPamDataset
 {
     friend class PNGRasterBand;
 
-    VSILFILE        *fpImage;
+    VSILFILE *fpImage;
     png_structp hPNG;
-    png_infop   psPNGInfo;
-    int         nBitDepth;
-    int         nColorType;  // PNG_COLOR_TYPE_*
-    int         bInterlaced;
+    png_infop psPNGInfo;
+    int nBitDepth;
+    int nColorType;  // PNG_COLOR_TYPE_*
+    int bInterlaced;
 
-    int         nBufferStartLine;
-    int         nBufferLines;
-    int         nLastLineRead;
-    GByte      *pabyBuffer;
+    int nBufferStartLine;
+    int nBufferLines;
+    int nLastLineRead;
+    GByte *pabyBuffer;
 
     GDALColorTable *poColorTable;
 
-    int    bGeoTransformValid;
+    int bGeoTransformValid;
     double adfGeoTransform[6];
 
-    void        CollectMetadata();
+    void CollectMetadata();
 
-    int         bHasReadXMPMetadata;
-    void        CollectXMPMetadata();
+    int bHasReadXMPMetadata;
+    void CollectXMPMetadata();
 
-    CPLErr      LoadScanline( int );
-    CPLErr      LoadInterlacedChunk( int );
-    void        Restart();
+    CPLErr LoadScanline(int);
+    CPLErr LoadInterlacedChunk(int);
+    void Restart();
 
-    int         bHasTriedLoadWorldFile;
-    void        LoadWorldFile();
-    CPLString   osWldFilename;
+    int bHasTriedLoadWorldFile;
+    void LoadWorldFile();
+    CPLString osWldFilename;
 
-    int         bHasReadICCMetadata;
-    void        LoadICCProfile();
+    int bHasReadICCMetadata;
+    void LoadICCProfile();
 
-    static void WriteMetadataAsText(jmp_buf sSetJmpContext,
-                                    png_structp hPNG, png_infop psPNGInfo,
-                                    const char* pszKey, const char* pszValue);
-    static GDALDataset *OpenStage2( GDALOpenInfo *, PNGDataset*& );
+    static void WriteMetadataAsText(jmp_buf sSetJmpContext, png_structp hPNG,
+                                    png_infop psPNGInfo, const char *pszKey,
+                                    const char *pszValue);
+    static GDALDataset *OpenStage2(GDALOpenInfo *, PNGDataset *&);
 
   public:
-                 PNGDataset();
+    PNGDataset();
     virtual ~PNGDataset();
 
-    static GDALDataset *Open( GDALOpenInfo * );
-    static int          Identify( GDALOpenInfo * );
-    static GDALDataset* CreateCopy( const char * pszFilename,
-                                    GDALDataset *poSrcDS,
-                                    int bStrict, char ** papszOptions,
-                                    GDALProgressFunc pfnProgress,
-                                    void * pProgressData );
+    static GDALDataset *Open(GDALOpenInfo *);
+    static int Identify(GDALOpenInfo *);
+    static GDALDataset *CreateCopy(const char *pszFilename,
+                                   GDALDataset *poSrcDS, int bStrict,
+                                   char **papszOptions,
+                                   GDALProgressFunc pfnProgress,
+                                   void *pProgressData);
 
     virtual char **GetFileList(void) override;
 
-    virtual CPLErr GetGeoTransform( double * ) override;
-    virtual void FlushCache( bool bAtClosing ) override;
+    virtual CPLErr GetGeoTransform(double *) override;
+    virtual void FlushCache(bool bAtClosing) override;
 
-    virtual char      **GetMetadataDomainList() override;
+    virtual char **GetMetadataDomainList() override;
 
-    virtual char  **GetMetadata( const char * pszDomain = "" ) override;
-    virtual const char *GetMetadataItem( const char * pszName,
-                                         const char * pszDomain = nullptr ) override;
+    virtual char **GetMetadata(const char *pszDomain = "") override;
+    virtual const char *
+    GetMetadataItem(const char *pszName,
+                    const char *pszDomain = nullptr) override;
 
-    virtual CPLErr      IRasterIO( GDALRWFlag, int, int, int, int,
-                                   void *, int, int, GDALDataType,
-                                   int, int *,
-                                   GSpacing, GSpacing,
-                                   GSpacing,
-                                   GDALRasterIOExtraArg* psExtraArg ) override;
+    virtual CPLErr IRasterIO(GDALRWFlag, int, int, int, int, void *, int, int,
+                             GDALDataType, int, int *, GSpacing, GSpacing,
+                             GSpacing,
+                             GDALRasterIOExtraArg *psExtraArg) override;
 
-    jmp_buf     sSetJmpContext;  // Semi-private.
+    jmp_buf sSetJmpContext;  // Semi-private.
 
 #ifdef SUPPORT_CREATE
-    int        m_nBitDepth;
-    GByte      *m_pabyBuffer;
-    png_byte    *m_pabyAlpha;
+    int m_nBitDepth;
+    GByte *m_pabyBuffer;
+    png_byte *m_pabyAlpha;
     png_structp m_hPNG;
-    png_infop   m_psPNGInfo;
-    png_color   *m_pasPNGColors;
-    VSILFILE        *m_fpImage;
-    int    m_bGeoTransformValid;
+    png_infop m_psPNGInfo;
+    png_color *m_pasPNGColors;
+    VSILFILE *m_fpImage;
+    int m_bGeoTransformValid;
     double m_adfGeoTransform[6];
-    char        *m_pszFilename;
-    int         m_nColorType;  // PNG_COLOR_TYPE_*
+    char *m_pszFilename;
+    int m_nColorType;  // PNG_COLOR_TYPE_*
+
+    virtual CPLErr SetGeoTransform(double *);
+    static GDALDataset *Create(const char *pszFilename, int nXSize, int nYSize,
+                               int nBands, GDALDataType, char **papszParamList);
 
-    virtual CPLErr SetGeoTransform( double * );
-    static GDALDataset  *Create( const char* pszFilename,
-                                int nXSize, int nYSize, int nBands,
-                                GDALDataType, char** papszParamList );
   protected:
-        CPLErr write_png_header();
+    CPLErr write_png_header();
 
 #endif
 };
 
 #ifdef _MSC_VER
-#pragma warning( pop )
+#pragma warning(pop)
 #endif
 
 /************************************************************************/
@@ -187,37 +186,44 @@ class PNGDataset final: public GDALPamDataset
 /* ==================================================================== */
 /************************************************************************/
 
-class PNGRasterBand final: public GDALPamRasterBand
+class PNGRasterBand final : public GDALPamRasterBand
 {
     friend class PNGDataset;
 
   public:
+    PNGRasterBand(PNGDataset *, int);
+    virtual ~PNGRasterBand()
+    {
+    }
 
-                   PNGRasterBand( PNGDataset *, int );
-    virtual ~PNGRasterBand() {}
+    virtual CPLErr IReadBlock(int, int, void *) override;
 
-    virtual CPLErr IReadBlock( int, int, void * ) override;
+    virtual GDALSuggestedBlockAccessPattern
+    GetSuggestedBlockAccessPattern() const override
+    {
+        return GSBAP_TOP_TO_BOTTOM;
+    }
 
     virtual GDALColorInterp GetColorInterpretation() override;
     virtual GDALColorTable *GetColorTable() override;
-    CPLErr SetNoDataValue( double dfNewValue ) override;
-    virtual double GetNoDataValue( int *pbSuccess = nullptr ) override;
+    CPLErr SetNoDataValue(double dfNewValue) override;
+    virtual double GetNoDataValue(int *pbSuccess = nullptr) override;
 
-    int         bHaveNoData;
-    double      dfNoDataValue;
+    int bHaveNoData;
+    double dfNoDataValue;
 
 #ifdef SUPPORT_CREATE
-    virtual CPLErr SetColorTable(GDALColorTable*);
-    virtual CPLErr IWriteBlock( int, int, void * ) override;
+    virtual CPLErr SetColorTable(GDALColorTable *);
+    virtual CPLErr IWriteBlock(int, int, void *) override;
 
   protected:
-        int m_bBandProvided[5];
-        void reset_band_provision_flags()
-        {
-            PNGDataset& ds = *reinterpret_cast<PNGDataset *>( poDS );
+    int m_bBandProvided[5];
+    void reset_band_provision_flags()
+    {
+        PNGDataset &ds = *reinterpret_cast<PNGDataset *>(poDS);
 
-            for(size_t i = 0; i < static_cast<size_t>( ds.nBands ); i++)
-                m_bBandProvided[i] = FALSE;
-        }
+        for (size_t i = 0; i < static_cast<size_t>(ds.nBands); i++)
+            m_bBandProvided[i] = FALSE;
+    }
 #endif
 };
