@@ -30,20 +30,14 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id$")
-
 /************************************************************************/
 /*                          OGRDWGDataSource()                          */
 /************************************************************************/
 
-OGRDWGDataSource::OGRDWGDataSource() :
-  fp(nullptr),
-  iEntitiesSectionOffset(0),
-  bInlineBlocks(FALSE),
-  bAttributes(FALSE),
-  bAllAttributes(TRUE),
-  poServices(nullptr),
-  poDb(static_cast<const OdRxObject*>(nullptr))
+OGRDWGDataSource::OGRDWGDataSource()
+    : fp(nullptr), iEntitiesSectionOffset(0), bInlineBlocks(FALSE),
+      bAttributes(FALSE), bAllAttributes(TRUE), poServices(nullptr),
+      poDb(static_cast<const OdRxObject *>(nullptr))
 
 {
 }
@@ -55,10 +49,10 @@ OGRDWGDataSource::OGRDWGDataSource() :
 OGRDWGDataSource::~OGRDWGDataSource()
 
 {
-/* -------------------------------------------------------------------- */
-/*      Destroy layers.                                                 */
-/* -------------------------------------------------------------------- */
-    while( !apoLayers.empty() )
+    /* -------------------------------------------------------------------- */
+    /*      Destroy layers.                                                 */
+    /* -------------------------------------------------------------------- */
+    while (!apoLayers.empty())
     {
         delete apoLayers.back();
         apoLayers.pop_back();
@@ -69,7 +63,7 @@ OGRDWGDataSource::~OGRDWGDataSource()
 /*                           TestCapability()                           */
 /************************************************************************/
 
-int OGRDWGDataSource::TestCapability( const char * /*pszCap*/ )
+int OGRDWGDataSource::TestCapability(const char * /*pszCap*/)
 
 {
     return FALSE;
@@ -79,10 +73,10 @@ int OGRDWGDataSource::TestCapability( const char * /*pszCap*/ )
 /*                              GetLayer()                              */
 /************************************************************************/
 
-OGRLayer *OGRDWGDataSource::GetLayer( int iLayer )
+OGRLayer *OGRDWGDataSource::GetLayer(int iLayer)
 
 {
-    if( iLayer < 0 || iLayer >= (int) apoLayers.size() )
+    if (iLayer < 0 || iLayer >= (int)apoLayers.size())
         return nullptr;
     else
         return apoLayers[iLayer];
@@ -92,8 +86,8 @@ OGRLayer *OGRDWGDataSource::GetLayer( int iLayer )
 /*                                Open()                                */
 /************************************************************************/
 
-int OGRDWGDataSource::Open( OGRDWGServices *poServicesIn,
-                            const char * pszFilename, int /*bHeaderOnly*/ )
+int OGRDWGDataSource::Open(OGRDWGServices *poServicesIn,
+                           const char *pszFilename, int /*bHeaderOnly*/)
 
 {
     poServices = poServicesIn;
@@ -102,66 +96,64 @@ int OGRDWGDataSource::Open( OGRDWGServices *poServicesIn,
 
     m_osName = pszFilename;
 
-    bInlineBlocks = CPLTestBool(
-        CPLGetConfigOption( "DWG_INLINE_BLOCKS", "TRUE" ) );
-    bAttributes = CPLTestBool(
-    CPLGetConfigOption( "DWG_ATTRIBUTES", "FALSE" ) );
-    bAllAttributes = CPLTestBool(
-        CPLGetConfigOption("DWG_ALL_ATTRIBUTES", "TRUE"));
+    bInlineBlocks =
+        CPLTestBool(CPLGetConfigOption("DWG_INLINE_BLOCKS", "TRUE"));
+    bAttributes = CPLTestBool(CPLGetConfigOption("DWG_ATTRIBUTES", "FALSE"));
+    bAllAttributes =
+        CPLTestBool(CPLGetConfigOption("DWG_ALL_ATTRIBUTES", "TRUE"));
 
-/* -------------------------------------------------------------------- */
-/*      Open the file.                                                  */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Open the file.                                                  */
+    /* -------------------------------------------------------------------- */
     try
     {
         OdString f(pszFilename);
         poDb = poServices->readFile(f.c_str(), true, false, Oda::kShareDenyNo);
     }
-    catch( OdError& e )
+    catch (OdError &e)
     {
-        CPLError( CE_Failure, CPLE_AppDefined,
-                  "%s",
-                  (const char *) poServices->getErrorDescription(e.code()) );
+        CPLError(CE_Failure, CPLE_AppDefined, "%s",
+                 (const char *)poServices->getErrorDescription(e.code()));
     }
-    catch( ... )
+    catch (...)
     {
-        CPLError( CE_Failure, CPLE_AppDefined,
-                  "DWG readFile(%s) failed with generic exception.",
-                  pszFilename );
+        CPLError(CE_Failure, CPLE_AppDefined,
+                 "DWG readFile(%s) failed with generic exception.",
+                 pszFilename);
     }
 
-    if( poDb.isNull() )
+    if (poDb.isNull())
         return FALSE;
 
-/* -------------------------------------------------------------------- */
-/*      Process the header, picking up a few useful pieces of           */
-/*      information.                                                    */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Process the header, picking up a few useful pieces of           */
+    /*      information.                                                    */
+    /* -------------------------------------------------------------------- */
     ReadHeaderSection();
     ReadLineTypeDefinitions();
     ReadLayerDefinitions();
 
-/* -------------------------------------------------------------------- */
-/*      Create a blocks layer if we are not in inlining mode.           */
-/* -------------------------------------------------------------------- */
-    if( !bInlineBlocks )
-        apoLayers.push_back( new OGRDWGBlocksLayer( this ) );
+    /* -------------------------------------------------------------------- */
+    /*      Create a blocks layer if we are not in inlining mode.           */
+    /* -------------------------------------------------------------------- */
+    if (!bInlineBlocks)
+        apoLayers.push_back(new OGRDWGBlocksLayer(this));
 
-/* -------------------------------------------------------------------- */
-/*      Create out layer object - we will need it when interpreting     */
-/*      blocks.                                                         */
-/* -------------------------------------------------------------------- */
-    if(bAttributes){
+    /* -------------------------------------------------------------------- */
+    /*      Create out layer object - we will need it when interpreting     */
+    /*      blocks.                                                         */
+    /* -------------------------------------------------------------------- */
+    if (bAttributes)
+    {
         ReadAttDefinitions();
     }
-    apoLayers.push_back( new OGRDWGLayer( this ) );
+    apoLayers.push_back(new OGRDWGLayer(this));
 
     ReadBlocksSection();
 
     return TRUE;
 }
 
-
 /************************************************************************/
 /*                        ReadAttDefinitions()                          */
 /************************************************************************/
@@ -171,40 +163,47 @@ void OGRDWGDataSource::ReadAttDefinitions()
 {
     OdDbBlockTablePtr pTable = poDb->getBlockTableId().safeOpenObject();
     OdDbSymbolTableIteratorPtr pBlkIter = pTable->newIterator();
-    OdDbBlockTableRecordPtr  poModelSpace, poBlock;
-  
+    OdDbBlockTableRecordPtr poModelSpace, poBlock;
+
     for (pBlkIter->start(); !pBlkIter->done(); pBlkIter->step())
     {
         poBlock = pBlkIter->getRecordId().safeOpenObject();
         OdDbObjectIteratorPtr poEntIter = poBlock->newIterator();
 
-        CPLString* attName = nullptr;
-        /* -------------------------------------------------------------------- */
-        /*      Fetch the next attribute definition.                            */
-        /* -------------------------------------------------------------------- */
+        CPLString *attName = nullptr;
+        /* --------------------------------------------------------------------
+         */
+        /*      Fetch the next attribute definition. */
+        /* --------------------------------------------------------------------
+         */
         for (poEntIter->start(); !poEntIter->done(); poEntIter->step())
         {
             OdDbObjectId oId = poEntIter->objectId();
             OdDbEntityPtr poEntity = OdDbEntity::cast(oId.openObject());
             if (poEntity.isNull())
                 continue;
-            /* -------------------------------------------------------------------- */
-            /*      Check AcDbAttributeDefinition then create and insert attribute  */
-            /* -------------------------------------------------------------------- */
-            OdRxClass* poClass = poEntity->isA();
+            /* --------------------------------------------------------------------
+             */
+            /*      Check AcDbAttributeDefinition then create and insert
+             * attribute  */
+            /* --------------------------------------------------------------------
+             */
+            OdRxClass *poClass = poEntity->isA();
             const OdString osName = poClass->name();
-            const char* pszEntityClassName =  osName;
+            const char *pszEntityClassName = osName;
             if (EQUAL(pszEntityClassName, "AcDbAttributeDefinition"))
             {
-                OdDbAttributeDefinitionPtr poAttributeDefinition = OdDbAttributeDefinition::cast(poEntity);
-                if (bAllAttributes || !poAttributeDefinition->isInvisible()) {
-                    const char* tagName = poAttributeDefinition->tag();
+                OdDbAttributeDefinitionPtr poAttributeDefinition =
+                    OdDbAttributeDefinition::cast(poEntity);
+                if (bAllAttributes || !poAttributeDefinition->isInvisible())
+                {
+                    const char *tagName = poAttributeDefinition->tag();
                     attName = new CPLString(tagName);
-                    if (attributeFields.count(*attName) == 0) {
+                    if (attributeFields.count(*attName) == 0)
+                    {
                         attributeFields.insert(*attName);
                     }
                 }
-
             }
         }
     }
@@ -223,23 +222,25 @@ void OGRDWGDataSource::ReadLayerDefinitions()
     {
         CPLString osValue;
         OdDbLayerTableRecordPtr poLD = poIter->getRecordId().safeOpenObject();
-        std::map<CPLString,CPLString> oLayerProperties;
+        std::map<CPLString, CPLString> oLayerProperties;
 
-        CPLString osLayerName = ACTextUnescape(poLD->getName(),GetEncoding(), false);
+        CPLString osLayerName =
+            ACTextUnescape(poLD->getName(), GetEncoding(), false);
 
         oLayerProperties["Exists"] = "1";
 
-        OdDbLinetypeTableRecordPtr poLinetypeTableRecord = poLD->linetypeObjectId().safeOpenObject();
-        oLayerProperties["Linetype"] =
-            ACTextUnescape(poLinetypeTableRecord->getName(),GetEncoding(), false);
+        OdDbLinetypeTableRecordPtr poLinetypeTableRecord =
+            poLD->linetypeObjectId().safeOpenObject();
+        oLayerProperties["Linetype"] = ACTextUnescape(
+            poLinetypeTableRecord->getName(), GetEncoding(), false);
 
-        osValue.Printf( "%d", poLD->colorIndex() );
+        osValue.Printf("%d", poLD->colorIndex());
         oLayerProperties["Color"] = osValue;
 
-        osValue.Printf( "%d", (int) poLD->lineWeight() );
+        osValue.Printf("%d", (int)poLD->lineWeight());
         oLayerProperties["LineWeight"] = osValue;
 
-        if( poLD->isFrozen() || poLD->isHidden() || poLD->isOff() )
+        if (poLD->isFrozen() || poLD->isHidden() || poLD->isOff())
             oLayerProperties["Hidden"] = "1";
         else
             oLayerProperties["Hidden"] = "0";
@@ -247,24 +248,26 @@ void OGRDWGDataSource::ReadLayerDefinitions()
         oLayerTable[osLayerName] = oLayerProperties;
     }
 
-    CPLDebug( "DWG", "Read %d layer definitions.",
-              (int) oLayerTable.size() );
+    CPLDebug("DWG", "Read %d layer definitions.", (int)oLayerTable.size());
 }
 
 /************************************************************************/
 /*                        LookupLayerProperty()                         */
 /************************************************************************/
 
-const char *OGRDWGDataSource::LookupLayerProperty( const char *pszLayer,
-                                                   const char *pszProperty )
+const char *OGRDWGDataSource::LookupLayerProperty(const char *pszLayer,
+                                                  const char *pszProperty)
 
 {
-    if( pszLayer == nullptr )
+    if (pszLayer == nullptr)
         return nullptr;
 
-    try {
+    try
+    {
         return (oLayerTable[pszLayer])[pszProperty];
-    } catch( ... ) {
+    }
+    catch (...)
+    {
         return nullptr;
     }
 }
@@ -283,28 +286,28 @@ void OGRDWGDataSource::ReadLineTypeDefinitions()
     {
         CPLString osLineTypeName;
         CPLString osLineTypeDef;
-        OdDbLinetypeTableRecordPtr poLT = poIter->getRecordId().safeOpenObject();
+        OdDbLinetypeTableRecordPtr poLT =
+            poIter->getRecordId().safeOpenObject();
 
-        osLineTypeName = ACTextUnescape(poLT->getName(),GetEncoding(),false);
+        osLineTypeName = ACTextUnescape(poLT->getName(), GetEncoding(), false);
 
         if (poLT->numDashes())
         {
-            for (int i=0; i < poLT->numDashes(); i++)
+            for (int i = 0; i < poLT->numDashes(); i++)
             {
-                if( i > 0 )
+                if (i > 0)
                     osLineTypeDef += " ";
 
                 CPLString osValue;
-                osValue.Printf( "%g", fabs(poLT->dashLengthAt(i)) );
+                osValue.Printf("%g", fabs(poLT->dashLengthAt(i)));
                 osLineTypeDef += osValue;
 
                 osLineTypeDef += "g";
             }
 
             oLineTypeTable[osLineTypeName] = osLineTypeDef;
-            CPLDebug( "DWG", "LineType '%s' = '%s'",
-                       osLineTypeName.c_str(),
-                       osLineTypeDef.c_str() );
+            CPLDebug("DWG", "LineType '%s' = '%s'", osLineTypeName.c_str(),
+                     osLineTypeDef.c_str());
         }
     }
 }
@@ -313,10 +316,10 @@ void OGRDWGDataSource::ReadLineTypeDefinitions()
 /*                           LookupLineType()                           */
 /************************************************************************/
 
-const char *OGRDWGDataSource::LookupLineType( const char *pszName )
+const char *OGRDWGDataSource::LookupLineType(const char *pszName)
 
 {
-    if( oLineTypeTable.count(pszName) > 0 )
+    if (oLineTypeTable.count(pszName) > 0)
         return oLineTypeTable[pszName];
     else
         return nullptr;
@@ -333,25 +336,24 @@ void OGRDWGDataSource::ReadHeaderSection()
 
     CPLString osValue;
 
-    osValue.Printf( "%d", poDb->getLUPREC() );
+    osValue.Printf("%d", poDb->getLUPREC());
     oHeaderVariables["$LUPREC"] = osValue;
 
-    osValue.Printf( "%g", poDb->dimtxt() );
+    osValue.Printf("%g", poDb->dimtxt());
     oHeaderVariables["$DIMTXT"] = osValue;
 
-    CPLDebug( "DWG", "Read %d header variables.",
-              (int) oHeaderVariables.size() );
+    CPLDebug("DWG", "Read %d header variables.", (int)oHeaderVariables.size());
 
-/* -------------------------------------------------------------------- */
-/*      Decide on what CPLRecode() name to use for the files            */
-/*      encoding or allow the encoding to be overridden.                */
-/* -------------------------------------------------------------------- */
-    CPLString osCodepage = GetVariable( "$DWGCODEPAGE", "ANSI_1252" );
+    /* -------------------------------------------------------------------- */
+    /*      Decide on what CPLRecode() name to use for the files            */
+    /*      encoding or allow the encoding to be overridden.                */
+    /* -------------------------------------------------------------------- */
+    CPLString osCodepage = GetVariable("$DWGCODEPAGE", "ANSI_1252");
 
     // not strictly accurate but works even without iconv.
-    if( osCodepage == "ANSI_1252" )
+    if (osCodepage == "ANSI_1252")
         osEncoding = CPL_ENC_ISO8859_1;
-    else if( STARTS_WITH_CI(osCodepage, "ANSI_") )
+    else if (STARTS_WITH_CI(osCodepage, "ANSI_"))
     {
         osEncoding = "CP";
         osEncoding += osCodepage + 5;
@@ -362,12 +364,12 @@ void OGRDWGDataSource::ReadHeaderSection()
         osEncoding = CPL_ENC_ISO8859_1;
     }
 
-    if( CPLGetConfigOption( "DWG_ENCODING", nullptr ) != nullptr )
-        osEncoding = CPLGetConfigOption( "DWG_ENCODING", nullptr );
+    if (CPLGetConfigOption("DWG_ENCODING", nullptr) != nullptr)
+        osEncoding = CPLGetConfigOption("DWG_ENCODING", nullptr);
 
-    if( osEncoding != CPL_ENC_ISO8859_1 )
-        CPLDebug( "DWG", "Treating DWG as encoding '%s', $DWGCODEPAGE='%s'",
-                  osEncoding.c_str(), osCodepage.c_str() );
+    if (osEncoding != CPL_ENC_ISO8859_1)
+        CPLDebug("DWG", "Treating DWG as encoding '%s', $DWGCODEPAGE='%s'",
+                 osEncoding.c_str(), osCodepage.c_str());
 }
 
 /************************************************************************/
@@ -376,11 +378,11 @@ void OGRDWGDataSource::ReadHeaderSection()
 /*      Fetch a variable that came from the HEADER section.             */
 /************************************************************************/
 
-const char *OGRDWGDataSource::GetVariable( const char *pszName,
-                                           const char *pszDefault )
+const char *OGRDWGDataSource::GetVariable(const char *pszName,
+                                          const char *pszDefault)
 
 {
-    if( oHeaderVariables.count(pszName) == 0 )
+    if (oHeaderVariables.count(pszName) == 0)
         return pszDefault;
     else
         return oHeaderVariables[pszName];
@@ -390,34 +392,34 @@ const char *OGRDWGDataSource::GetVariable( const char *pszName,
 /*                         AddStandardFields()                          */
 /************************************************************************/
 
-void OGRDWGDataSource::AddStandardFields( OGRFeatureDefn *poFeatureDefn )
+void OGRDWGDataSource::AddStandardFields(OGRFeatureDefn *poFeatureDefn)
 
 {
-    OGRFieldDefn  oLayerField( "Layer", OFTString );
-    poFeatureDefn->AddFieldDefn( &oLayerField );
+    OGRFieldDefn oLayerField("Layer", OFTString);
+    poFeatureDefn->AddFieldDefn(&oLayerField);
 
-    OGRFieldDefn  oClassField( "SubClasses", OFTString );
-    poFeatureDefn->AddFieldDefn( &oClassField );
+    OGRFieldDefn oClassField("SubClasses", OFTString);
+    poFeatureDefn->AddFieldDefn(&oClassField);
 
-    OGRFieldDefn  oExtendedField( "ExtendedEntity", OFTString );
-    poFeatureDefn->AddFieldDefn( &oExtendedField );
+    OGRFieldDefn oExtendedField("ExtendedEntity", OFTString);
+    poFeatureDefn->AddFieldDefn(&oExtendedField);
 
-    OGRFieldDefn  oLinetypeField( "Linetype", OFTString );
-    poFeatureDefn->AddFieldDefn( &oLinetypeField );
+    OGRFieldDefn oLinetypeField("Linetype", OFTString);
+    poFeatureDefn->AddFieldDefn(&oLinetypeField);
 
-    OGRFieldDefn  oEntityHandleField( "EntityHandle", OFTString );
-    poFeatureDefn->AddFieldDefn( &oEntityHandleField );
+    OGRFieldDefn oEntityHandleField("EntityHandle", OFTString);
+    poFeatureDefn->AddFieldDefn(&oEntityHandleField);
 
-    OGRFieldDefn  oTextField( "Text", OFTString );
-    poFeatureDefn->AddFieldDefn( &oTextField );
+    OGRFieldDefn oTextField("Text", OFTString);
+    poFeatureDefn->AddFieldDefn(&oTextField);
 
-    if( !bInlineBlocks )
+    if (!bInlineBlocks)
     {
-        OGRFieldDefn  oBlockNameField( "BlockName", OFTString );
-        poFeatureDefn->AddFieldDefn( &oBlockNameField );
+        OGRFieldDefn oBlockNameField("BlockName", OFTString);
+        poFeatureDefn->AddFieldDefn(&oBlockNameField);
 
-        OGRFieldDefn  oBlockAttrField( "BlockAttributes", OFTString );
+        OGRFieldDefn oBlockAttrField("BlockAttributes", OFTString);
         oBlockAttrField.SetSubType(OFSTJSON);
-        poFeatureDefn->AddFieldDefn( &oBlockAttrField );
+        poFeatureDefn->AddFieldDefn(&oBlockAttrField);
     }
 }
