@@ -29,17 +29,14 @@
 #ifndef DOXYGEN_SKIP
 
 #include "ogrlayerpool.h"
-
-CPL_CVSID("$Id: ogrlayerpool.cpp 355b41831cd2685c85d1aabe5b95665a2c6e99b7 2019-06-19 17:07:04 +0200 Even Rouault $")
+#include "ogr_recordbatch.h"
 
 /************************************************************************/
 /*                      OGRAbstractProxiedLayer()                       */
 /************************************************************************/
 
-OGRAbstractProxiedLayer::OGRAbstractProxiedLayer( OGRLayerPool* poPoolIn ) :
-    poPrevLayer(nullptr),
-    poNextLayer(nullptr),
-    poPool(poPoolIn)
+OGRAbstractProxiedLayer::OGRAbstractProxiedLayer(OGRLayerPool *poPoolIn)
+    : poPrevLayer(nullptr), poNextLayer(nullptr), poPool(poPoolIn)
 {
     CPLAssert(poPoolIn != nullptr);
 }
@@ -58,12 +55,11 @@ OGRAbstractProxiedLayer::~OGRAbstractProxiedLayer()
 /*                            OGRLayerPool()                            */
 /************************************************************************/
 
-OGRLayerPool::OGRLayerPool(int nMaxSimultaneouslyOpenedIn) :
-    poMRULayer(nullptr),
-    poLRULayer(nullptr),
-    nMRUListSize(0),
-    nMaxSimultaneouslyOpened(nMaxSimultaneouslyOpenedIn)
-{}
+OGRLayerPool::OGRLayerPool(int nMaxSimultaneouslyOpenedIn)
+    : poMRULayer(nullptr), poLRULayer(nullptr), nMRUListSize(0),
+      nMaxSimultaneouslyOpened(nMaxSimultaneouslyOpenedIn)
+{
+}
 
 /************************************************************************/
 /*                           ~OGRLayerPool()                            */
@@ -71,22 +67,22 @@ OGRLayerPool::OGRLayerPool(int nMaxSimultaneouslyOpenedIn) :
 
 OGRLayerPool::~OGRLayerPool()
 {
-    CPLAssert( poMRULayer == nullptr );
-    CPLAssert( poLRULayer == nullptr );
-    CPLAssert( nMRUListSize == 0 );
+    CPLAssert(poMRULayer == nullptr);
+    CPLAssert(poLRULayer == nullptr);
+    CPLAssert(nMRUListSize == 0);
 }
 
 /************************************************************************/
 /*                          SetLastUsedLayer()                          */
 /************************************************************************/
 
-void OGRLayerPool::SetLastUsedLayer(OGRAbstractProxiedLayer* poLayer)
+void OGRLayerPool::SetLastUsedLayer(OGRAbstractProxiedLayer *poLayer)
 {
     /* If we are already the MRU layer, nothing to do */
     if (poLayer == poMRULayer)
         return;
 
-    //CPLDebug("OGR", "SetLastUsedLayer(%s)", poLayer->GetName());
+    // CPLDebug("OGR", "SetLastUsedLayer(%s)", poLayer->GetName());
 
     if (poLayer->poPrevLayer != nullptr || poLayer->poNextLayer != nullptr)
     {
@@ -116,23 +112,24 @@ void OGRLayerPool::SetLastUsedLayer(OGRAbstractProxiedLayer* poLayer)
     poMRULayer = poLayer;
     if (poLRULayer == nullptr)
         poLRULayer = poLayer;
-    nMRUListSize ++;
+    nMRUListSize++;
 }
 
 /************************************************************************/
 /*                           UnchainLayer()                             */
 /************************************************************************/
 
-void OGRLayerPool::UnchainLayer(OGRAbstractProxiedLayer* poLayer)
+void OGRLayerPool::UnchainLayer(OGRAbstractProxiedLayer *poLayer)
 {
-    OGRAbstractProxiedLayer* poPrevLayer = poLayer->poPrevLayer;
-    OGRAbstractProxiedLayer* poNextLayer = poLayer->poNextLayer;
+    OGRAbstractProxiedLayer *poPrevLayer = poLayer->poPrevLayer;
+    OGRAbstractProxiedLayer *poNextLayer = poLayer->poNextLayer;
 
     CPLAssert(poPrevLayer == nullptr || poPrevLayer->poNextLayer == poLayer);
     CPLAssert(poNextLayer == nullptr || poNextLayer->poPrevLayer == poLayer);
 
-    if (poPrevLayer != nullptr || poNextLayer != nullptr || poLayer == poMRULayer)
-        nMRUListSize --;
+    if (poPrevLayer != nullptr || poNextLayer != nullptr ||
+        poLayer == poMRULayer)
+        nMRUListSize--;
 
     if (poLayer == poMRULayer)
         poMRULayer = poNextLayer;
@@ -150,17 +147,13 @@ void OGRLayerPool::UnchainLayer(OGRAbstractProxiedLayer* poLayer)
 /*                          OGRProxiedLayer()                           */
 /************************************************************************/
 
-OGRProxiedLayer::OGRProxiedLayer( OGRLayerPool* poPoolIn,
-                                  OpenLayerFunc pfnOpenLayerIn,
-                                  FreeUserDataFunc pfnFreeUserDataIn,
-                                  void* pUserDataIn ) :
-    OGRAbstractProxiedLayer(poPoolIn),
-    pfnOpenLayer(pfnOpenLayerIn),
-    pfnFreeUserData(pfnFreeUserDataIn),
-    pUserData(pUserDataIn),
-    poUnderlyingLayer(nullptr),
-    poFeatureDefn(nullptr),
-    poSRS(nullptr)
+OGRProxiedLayer::OGRProxiedLayer(OGRLayerPool *poPoolIn,
+                                 OpenLayerFunc pfnOpenLayerIn,
+                                 FreeUserDataFunc pfnFreeUserDataIn,
+                                 void *pUserDataIn)
+    : OGRAbstractProxiedLayer(poPoolIn), pfnOpenLayer(pfnOpenLayerIn),
+      pfnFreeUserData(pfnFreeUserDataIn), pUserData(pUserDataIn),
+      poUnderlyingLayer(nullptr), poFeatureDefn(nullptr), poSRS(nullptr)
 {
     CPLAssert(pfnOpenLayerIn != nullptr);
 }
@@ -173,13 +166,13 @@ OGRProxiedLayer::~OGRProxiedLayer()
 {
     delete poUnderlyingLayer;
 
-    if( poSRS )
+    if (poSRS)
         poSRS->Release();
 
-    if( poFeatureDefn )
+    if (poFeatureDefn)
         poFeatureDefn->Release();
 
-    if( pfnFreeUserData != nullptr )
+    if (pfnFreeUserData != nullptr)
         pfnFreeUserData(pUserData);
 }
 
@@ -193,10 +186,9 @@ int OGRProxiedLayer::OpenUnderlyingLayer()
     CPLAssert(poUnderlyingLayer == nullptr);
     poPool->SetLastUsedLayer(this);
     poUnderlyingLayer = pfnOpenLayer(pUserData);
-    if( poUnderlyingLayer == nullptr )
+    if (poUnderlyingLayer == nullptr)
     {
-        CPLError(CE_Failure, CPLE_FileIO,
-                 "Cannot open underlying layer");
+        CPLError(CE_Failure, CPLE_FileIO, "Cannot open underlying layer");
     }
     return poUnderlyingLayer != nullptr;
 }
@@ -216,9 +208,9 @@ void OGRProxiedLayer::CloseUnderlyingLayer()
 /*                          GetUnderlyingLayer()                        */
 /************************************************************************/
 
-OGRLayer* OGRProxiedLayer::GetUnderlyingLayer()
+OGRLayer *OGRProxiedLayer::GetUnderlyingLayer()
 {
-    if( poUnderlyingLayer == nullptr )
+    if (poUnderlyingLayer == nullptr)
     {
         //  If the open fails, poUnderlyingLayer will still be a nullptr
         // and the user will be warned by the open call.
@@ -234,7 +226,8 @@ OGRLayer* OGRProxiedLayer::GetUnderlyingLayer()
 
 OGRGeometry *OGRProxiedLayer::GetSpatialFilter()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return nullptr;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
     return poUnderlyingLayer->GetSpatialFilter();
 }
 
@@ -242,9 +235,10 @@ OGRGeometry *OGRProxiedLayer::GetSpatialFilter()
 /*                          SetSpatialFilter()                          */
 /************************************************************************/
 
-void        OGRProxiedLayer::SetSpatialFilter( OGRGeometry * poGeom )
+void OGRProxiedLayer::SetSpatialFilter(OGRGeometry *poGeom)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return;
     poUnderlyingLayer->SetSpatialFilter(poGeom);
 }
 
@@ -252,18 +246,20 @@ void        OGRProxiedLayer::SetSpatialFilter( OGRGeometry * poGeom )
 /*                          SetSpatialFilter()                          */
 /************************************************************************/
 
-void        OGRProxiedLayer::SetSpatialFilter( int iGeomField, OGRGeometry * poGeom )
+void OGRProxiedLayer::SetSpatialFilter(int iGeomField, OGRGeometry *poGeom)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return;
     poUnderlyingLayer->SetSpatialFilter(iGeomField, poGeom);
 }
 /************************************************************************/
 /*                          SetAttributeFilter()                        */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::SetAttributeFilter( const char * poAttrFilter )
+OGRErr OGRProxiedLayer::SetAttributeFilter(const char *poAttrFilter)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->SetAttributeFilter(poAttrFilter);
 }
 
@@ -271,9 +267,10 @@ OGRErr      OGRProxiedLayer::SetAttributeFilter( const char * poAttrFilter )
 /*                            ResetReading()                            */
 /************************************************************************/
 
-void        OGRProxiedLayer::ResetReading()
+void OGRProxiedLayer::ResetReading()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return;
     poUnderlyingLayer->ResetReading();
 }
 
@@ -283,17 +280,45 @@ void        OGRProxiedLayer::ResetReading()
 
 OGRFeature *OGRProxiedLayer::GetNextFeature()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return nullptr;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
     return poUnderlyingLayer->GetNextFeature();
 }
 
+/************************************************************************/
+/*                            GDALDataset()                             */
+/************************************************************************/
+
+GDALDataset *OGRProxiedLayer::GetDataset()
+{
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
+    return poUnderlyingLayer->GetDataset();
+}
+
+/************************************************************************/
+/*                          GetArrowStream()                            */
+/************************************************************************/
+
+bool OGRProxiedLayer::GetArrowStream(struct ArrowArrayStream *out_stream,
+                                     CSLConstList papszOptions)
+{
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+    {
+        memset(out_stream, 0, sizeof(*out_stream));
+        return false;
+    }
+    return poUnderlyingLayer->GetArrowStream(out_stream, papszOptions);
+}
+
 /************************************************************************/
 /*                           SetNextByIndex()                           */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::SetNextByIndex( GIntBig nIndex )
+OGRErr OGRProxiedLayer::SetNextByIndex(GIntBig nIndex)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->SetNextByIndex(nIndex);
 }
 
@@ -301,9 +326,10 @@ OGRErr      OGRProxiedLayer::SetNextByIndex( GIntBig nIndex )
 /*                             GetFeature()                             */
 /************************************************************************/
 
-OGRFeature *OGRProxiedLayer::GetFeature( GIntBig nFID )
+OGRFeature *OGRProxiedLayer::GetFeature(GIntBig nFID)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return nullptr;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
     return poUnderlyingLayer->GetFeature(nFID);
 }
 
@@ -311,9 +337,10 @@ OGRFeature *OGRProxiedLayer::GetFeature( GIntBig nFID )
 /*                             ISetFeature()                             */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::ISetFeature( OGRFeature *poFeature )
+OGRErr OGRProxiedLayer::ISetFeature(OGRFeature *poFeature)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->SetFeature(poFeature);
 }
 
@@ -321,19 +348,32 @@ OGRErr      OGRProxiedLayer::ISetFeature( OGRFeature *poFeature )
 /*                            ICreateFeature()                           */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::ICreateFeature( OGRFeature *poFeature )
+OGRErr OGRProxiedLayer::ICreateFeature(OGRFeature *poFeature)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->CreateFeature(poFeature);
 }
 
+/************************************************************************/
+/*                            IUpsertFeature()                          */
+/************************************************************************/
+
+OGRErr OGRProxiedLayer::IUpsertFeature(OGRFeature *poFeature)
+{
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
+    return poUnderlyingLayer->UpsertFeature(poFeature);
+}
+
 /************************************************************************/
 /*                           DeleteFeature()                            */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::DeleteFeature( GIntBig nFID )
+OGRErr OGRProxiedLayer::DeleteFeature(GIntBig nFID)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->DeleteFeature(nFID);
 }
 
@@ -343,7 +383,8 @@ OGRErr      OGRProxiedLayer::DeleteFeature( GIntBig nFID )
 
 const char *OGRProxiedLayer::GetName()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return "";
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return "";
     return poUnderlyingLayer->GetName();
 }
 
@@ -353,7 +394,8 @@ const char *OGRProxiedLayer::GetName()
 
 OGRwkbGeometryType OGRProxiedLayer::GetGeomType()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return wkbUnknown;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return wkbUnknown;
     return poUnderlyingLayer->GetGeomType();
 }
 
@@ -363,10 +405,10 @@ OGRwkbGeometryType OGRProxiedLayer::GetGeomType()
 
 OGRFeatureDefn *OGRProxiedLayer::GetLayerDefn()
 {
-    if( poFeatureDefn != nullptr )
+    if (poFeatureDefn != nullptr)
         return poFeatureDefn;
 
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() )
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
     {
         poFeatureDefn = new OGRFeatureDefn("");
     }
@@ -386,11 +428,12 @@ OGRFeatureDefn *OGRProxiedLayer::GetLayerDefn()
 
 OGRSpatialReference *OGRProxiedLayer::GetSpatialRef()
 {
-    if( poSRS != nullptr )
+    if (poSRS != nullptr)
         return poSRS;
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return nullptr;
-    OGRSpatialReference* poRet = poUnderlyingLayer->GetSpatialRef();
-    if( poRet != nullptr )
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
+    OGRSpatialReference *poRet = poUnderlyingLayer->GetSpatialRef();
+    if (poRet != nullptr)
     {
         poSRS = poRet;
         poSRS->Reference();
@@ -402,9 +445,10 @@ OGRSpatialReference *OGRProxiedLayer::GetSpatialRef()
 /*                          GetFeatureCount()                           */
 /************************************************************************/
 
-GIntBig         OGRProxiedLayer::GetFeatureCount( int bForce )
+GIntBig OGRProxiedLayer::GetFeatureCount(int bForce)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return 0;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return 0;
     return poUnderlyingLayer->GetFeatureCount(bForce);
 }
 
@@ -412,9 +456,11 @@ GIntBig         OGRProxiedLayer::GetFeatureCount( int bForce )
 /*                             GetExtent()                              */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::GetExtent(int iGeomField, OGREnvelope *psExtent, int bForce)
+OGRErr OGRProxiedLayer::GetExtent(int iGeomField, OGREnvelope *psExtent,
+                                  int bForce)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->GetExtent(iGeomField, psExtent, bForce);
 }
 
@@ -422,9 +468,10 @@ OGRErr      OGRProxiedLayer::GetExtent(int iGeomField, OGREnvelope *psExtent, in
 /*                             GetExtent()                              */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::GetExtent(OGREnvelope *psExtent, int bForce)
+OGRErr OGRProxiedLayer::GetExtent(OGREnvelope *psExtent, int bForce)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->GetExtent(psExtent, bForce);
 }
 
@@ -432,9 +479,10 @@ OGRErr      OGRProxiedLayer::GetExtent(OGREnvelope *psExtent, int bForce)
 /*                           TestCapability()                           */
 /************************************************************************/
 
-int         OGRProxiedLayer::TestCapability( const char * pszCapability )
+int OGRProxiedLayer::TestCapability(const char *pszCapability)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return FALSE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return FALSE;
     return poUnderlyingLayer->TestCapability(pszCapability);
 }
 
@@ -442,10 +490,10 @@ int         OGRProxiedLayer::TestCapability( const char * pszCapability )
 /*                            CreateField()                             */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::CreateField( OGRFieldDefn *poField,
-                                            int bApproxOK )
+OGRErr OGRProxiedLayer::CreateField(OGRFieldDefn *poField, int bApproxOK)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->CreateField(poField, bApproxOK);
 }
 
@@ -453,9 +501,10 @@ OGRErr      OGRProxiedLayer::CreateField( OGRFieldDefn *poField,
 /*                            DeleteField()                             */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::DeleteField( int iField )
+OGRErr OGRProxiedLayer::DeleteField(int iField)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->DeleteField(iField);
 }
 
@@ -463,9 +512,10 @@ OGRErr      OGRProxiedLayer::DeleteField( int iField )
 /*                            ReorderFields()                           */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::ReorderFields( int* panMap )
+OGRErr OGRProxiedLayer::ReorderFields(int *panMap)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->ReorderFields(panMap);
 }
 
@@ -473,19 +523,35 @@ OGRErr      OGRProxiedLayer::ReorderFields( int* panMap )
 /*                           AlterFieldDefn()                           */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::AlterFieldDefn( int iField, OGRFieldDefn* poNewFieldDefn, int nFlagsIn )
+OGRErr OGRProxiedLayer::AlterFieldDefn(int iField, OGRFieldDefn *poNewFieldDefn,
+                                       int nFlagsIn)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->AlterFieldDefn(iField, poNewFieldDefn, nFlagsIn);
 }
 
+/************************************************************************/
+/*                         AlterGeomFieldDefn()                         */
+/************************************************************************/
+
+OGRErr OGRProxiedLayer::AlterGeomFieldDefn(
+    int iGeomField, const OGRGeomFieldDefn *poNewGeomFieldDefn, int nFlagsIn)
+{
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
+    return poUnderlyingLayer->AlterGeomFieldDefn(iGeomField, poNewGeomFieldDefn,
+                                                 nFlagsIn);
+}
+
 /************************************************************************/
 /*                            SyncToDisk()                              */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::SyncToDisk()
+OGRErr OGRProxiedLayer::SyncToDisk()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->SyncToDisk();
 }
 
@@ -495,7 +561,8 @@ OGRErr      OGRProxiedLayer::SyncToDisk()
 
 OGRStyleTable *OGRProxiedLayer::GetStyleTable()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return nullptr;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return nullptr;
     return poUnderlyingLayer->GetStyleTable();
 }
 
@@ -503,9 +570,10 @@ OGRStyleTable *OGRProxiedLayer::GetStyleTable()
 /*                       SetStyleTableDirectly()                        */
 /************************************************************************/
 
-void        OGRProxiedLayer::SetStyleTableDirectly( OGRStyleTable *poStyleTable )
+void OGRProxiedLayer::SetStyleTableDirectly(OGRStyleTable *poStyleTable)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return;
     return poUnderlyingLayer->SetStyleTableDirectly(poStyleTable);
 }
 
@@ -513,9 +581,10 @@ void        OGRProxiedLayer::SetStyleTableDirectly( OGRStyleTable *poStyleTable
 /*                           SetStyleTable()                            */
 /************************************************************************/
 
-void        OGRProxiedLayer::SetStyleTable(OGRStyleTable *poStyleTable)
+void OGRProxiedLayer::SetStyleTable(OGRStyleTable *poStyleTable)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return;
     return poUnderlyingLayer->SetStyleTable(poStyleTable);
 }
 
@@ -523,9 +592,10 @@ void        OGRProxiedLayer::SetStyleTable(OGRStyleTable *poStyleTable)
 /*                          StartTransaction()                          */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::StartTransaction()
+OGRErr OGRProxiedLayer::StartTransaction()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->StartTransaction();
 }
 
@@ -533,9 +603,10 @@ OGRErr      OGRProxiedLayer::StartTransaction()
 /*                          CommitTransaction()                         */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::CommitTransaction()
+OGRErr OGRProxiedLayer::CommitTransaction()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->CommitTransaction();
 }
 
@@ -543,9 +614,10 @@ OGRErr      OGRProxiedLayer::CommitTransaction()
 /*                        RollbackTransaction()                         */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::RollbackTransaction()
+OGRErr OGRProxiedLayer::RollbackTransaction()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->RollbackTransaction();
 }
 
@@ -555,7 +627,8 @@ OGRErr      OGRProxiedLayer::RollbackTransaction()
 
 const char *OGRProxiedLayer::GetFIDColumn()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return "";
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return "";
     return poUnderlyingLayer->GetFIDColumn();
 }
 
@@ -565,7 +638,8 @@ const char *OGRProxiedLayer::GetFIDColumn()
 
 const char *OGRProxiedLayer::GetGeometryColumn()
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return "";
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return "";
     return poUnderlyingLayer->GetGeometryColumn();
 }
 
@@ -573,10 +647,22 @@ const char *OGRProxiedLayer::GetGeometryColumn()
 /*                          SetIgnoredFields()                          */
 /************************************************************************/
 
-OGRErr      OGRProxiedLayer::SetIgnoredFields( const char **papszFields )
+OGRErr OGRProxiedLayer::SetIgnoredFields(const char **papszFields)
 {
-    if( poUnderlyingLayer == nullptr && !OpenUnderlyingLayer() ) return OGRERR_FAILURE;
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
     return poUnderlyingLayer->SetIgnoredFields(papszFields);
 }
 
+/************************************************************************/
+/*                              Rename()                                */
+/************************************************************************/
+
+OGRErr OGRProxiedLayer::Rename(const char *pszNewName)
+{
+    if (poUnderlyingLayer == nullptr && !OpenUnderlyingLayer())
+        return OGRERR_FAILURE;
+    return poUnderlyingLayer->Rename(pszNewName);
+}
+
 #endif /* #ifndef DOXYGEN_SKIP */
