@@ -46,11 +46,9 @@
 #include "ogrgeojsonutils.h"
 #include "ogrsf_frmts.h"
 
-CPL_CVSID("$Id: ogrgeojsondriver.cpp fa752ad6eabafaf630a704e1892a9d837d683cb3 2021-03-06 17:04:38 +0100 Even Rouault $")
-
-static CPLMutex* ghMutex = nullptr;
-static char* gpszSource = nullptr;
-static char* gpszText = nullptr;
+static CPLMutex *ghMutex = nullptr;
+static char *gpszSource = nullptr;
+static char *gpszText = nullptr;
 
 class OGRESRIFeatureServiceDataset;
 
@@ -58,60 +56,76 @@ class OGRESRIFeatureServiceDataset;
 /*                      OGRESRIFeatureServiceLayer                      */
 /************************************************************************/
 
-class OGRESRIFeatureServiceLayer final: public OGRLayer
+class OGRESRIFeatureServiceLayer final : public OGRLayer
 {
-    OGRESRIFeatureServiceDataset* poDS;
-    OGRFeatureDefn* poFeatureDefn;
-    GIntBig         nFeaturesRead;
-    GIntBig         nFirstFID;
-    GIntBig         nLastFID;
-    bool            bOtherPage;
-    bool            bUseSequentialFID;
+    OGRESRIFeatureServiceDataset *poDS;
+    OGRFeatureDefn *poFeatureDefn;
+    GIntBig nFeaturesRead;
+    GIntBig nFirstFID;
+    GIntBig nLastFID;
+    bool bOtherPage;
+    bool bUseSequentialFID;
 
   public:
-    explicit OGRESRIFeatureServiceLayer( OGRESRIFeatureServiceDataset* poDS );
+    explicit OGRESRIFeatureServiceLayer(OGRESRIFeatureServiceDataset *poDS);
     virtual ~OGRESRIFeatureServiceLayer();
 
     void ResetReading() override;
-    OGRFeature* GetNextFeature() override;
-    GIntBig GetFeatureCount( int bForce = TRUE ) override;
-    OGRErr              GetExtent(OGREnvelope *psExtent, int bForce = TRUE) override;
-    virtual OGRErr      GetExtent( int iGeomField, OGREnvelope *psExtent,
-                                   int bForce) override
-            { return OGRLayer::GetExtent(iGeomField, psExtent, bForce); }
-    int TestCapability( const char* pszCap ) override;
-    OGRFeatureDefn* GetLayerDefn() override { return poFeatureDefn; }
+    OGRFeature *GetNextFeature() override;
+    GIntBig GetFeatureCount(int bForce = TRUE) override;
+    OGRErr GetExtent(OGREnvelope *psExtent, int bForce = TRUE) override;
+    virtual OGRErr GetExtent(int iGeomField, OGREnvelope *psExtent,
+                             int bForce) override
+    {
+        return OGRLayer::GetExtent(iGeomField, psExtent, bForce);
+    }
+    int TestCapability(const char *pszCap) override;
+    OGRFeatureDefn *GetLayerDefn() override
+    {
+        return poFeatureDefn;
+    }
 };
 
 /************************************************************************/
 /*                       OGRESRIFeatureServiceDataset                   */
 /************************************************************************/
 
-class OGRESRIFeatureServiceDataset final: public GDALDataset
+class OGRESRIFeatureServiceDataset final : public GDALDataset
 {
-    CPLString              osURL;
-    GIntBig                nFirstOffset;
-    GIntBig                nLastOffset;
-    OGRGeoJSONDataSource  *poCurrent;
+    CPLString osURL;
+    GIntBig nFirstOffset;
+    GIntBig nLastOffset;
+    OGRGeoJSONDataSource *poCurrent;
     OGRESRIFeatureServiceLayer *poLayer;
 
-    int                     LoadPage();
+    int LoadPage();
 
   public:
-    OGRESRIFeatureServiceDataset( const CPLString &osURL,
-                                  OGRGeoJSONDataSource* poFirst );
+    OGRESRIFeatureServiceDataset(const CPLString &osURL,
+                                 OGRGeoJSONDataSource *poFirst);
     ~OGRESRIFeatureServiceDataset();
 
-    int GetLayerCount() override { return 1; }
-    OGRLayer* GetLayer( int nLayer ) override
-        { return (nLayer == 0) ? poLayer : nullptr; }
+    int GetLayerCount() override
+    {
+        return 1;
+    }
+    OGRLayer *GetLayer(int nLayer) override
+    {
+        return (nLayer == 0) ? poLayer : nullptr;
+    }
 
-    OGRLayer* GetUnderlyingLayer() { return poCurrent->GetLayer(0); }
+    OGRLayer *GetUnderlyingLayer()
+    {
+        return poCurrent->GetLayer(0);
+    }
 
     int MyResetReading();
     int LoadNextPage();
 
-    const CPLString& GetURL() { return osURL; }
+    const CPLString &GetURL()
+    {
+        return osURL;
+    }
 };
 
 /************************************************************************/
@@ -119,24 +133,20 @@ class OGRESRIFeatureServiceDataset final: public GDALDataset
 /************************************************************************/
 
 OGRESRIFeatureServiceLayer::OGRESRIFeatureServiceLayer(
-    OGRESRIFeatureServiceDataset* poDSIn) :
-    poDS(poDSIn),
-    nFeaturesRead(0),
-    nFirstFID(0),
-    nLastFID(0),
-    bOtherPage(false),
-    bUseSequentialFID(false)
+    OGRESRIFeatureServiceDataset *poDSIn)
+    : poDS(poDSIn), nFeaturesRead(0), nFirstFID(0), nLastFID(0),
+      bOtherPage(false), bUseSequentialFID(false)
 {
-    OGRFeatureDefn* poSrcFeatDefn = poDS->GetUnderlyingLayer()->GetLayerDefn();
+    OGRFeatureDefn *poSrcFeatDefn = poDS->GetUnderlyingLayer()->GetLayerDefn();
     poFeatureDefn = new OGRFeatureDefn(poSrcFeatDefn->GetName());
     SetDescription(poFeatureDefn->GetName());
     poFeatureDefn->Reference();
     poFeatureDefn->SetGeomType(wkbNone);
 
-    for( int i = 0; i < poSrcFeatDefn->GetFieldCount(); i++ )
+    for (int i = 0; i < poSrcFeatDefn->GetFieldCount(); i++)
         poFeatureDefn->AddFieldDefn(poSrcFeatDefn->GetFieldDefn(i));
 
-    for( int i = 0; i <poSrcFeatDefn->GetGeomFieldCount(); i++ )
+    for (int i = 0; i < poSrcFeatDefn->GetGeomFieldCount(); i++)
         poFeatureDefn->AddGeomFieldDefn(poSrcFeatDefn->GetGeomFieldDefn(i));
 }
 
@@ -166,51 +176,50 @@ void OGRESRIFeatureServiceLayer::ResetReading()
 /*                            GetNextFeature()                          */
 /************************************************************************/
 
-OGRFeature* OGRESRIFeatureServiceLayer::GetNextFeature()
+OGRFeature *OGRESRIFeatureServiceLayer::GetNextFeature()
 {
-    while( true )
+    while (true)
     {
         const bool bWasInFirstPage = !bOtherPage;
-        OGRFeature* poSrcFeat = poDS->GetUnderlyingLayer()->GetNextFeature();
-        if( poSrcFeat == nullptr )
+        OGRFeature *poSrcFeat = poDS->GetUnderlyingLayer()->GetNextFeature();
+        if (poSrcFeat == nullptr)
         {
-            if( !poDS->LoadNextPage() )
+            if (!poDS->LoadNextPage())
                 return nullptr;
             poSrcFeat = poDS->GetUnderlyingLayer()->GetNextFeature();
-            if( poSrcFeat == nullptr )
+            if (poSrcFeat == nullptr)
                 return nullptr;
             bOtherPage = true;
-            if( bWasInFirstPage && poSrcFeat->GetFID() != 0 &&
-                poSrcFeat->GetFID() == nFirstFID )
+            if (bWasInFirstPage && poSrcFeat->GetFID() != 0 &&
+                poSrcFeat->GetFID() == nFirstFID)
             {
                 // End-less looping
                 CPLDebug("ESRIJSON", "Scrolling not working. Stopping");
                 delete poSrcFeat;
                 return nullptr;
             }
-            if( bWasInFirstPage && poSrcFeat->GetFID() == 0 &&
-                nLastFID == nFeaturesRead - 1 )
+            if (bWasInFirstPage && poSrcFeat->GetFID() == 0 &&
+                nLastFID == nFeaturesRead - 1)
             {
                 bUseSequentialFID = true;
             }
         }
-        if( nFeaturesRead == 0 )
+        if (nFeaturesRead == 0)
             nFirstFID = poSrcFeat->GetFID();
 
-        OGRFeature* poFeature = new OGRFeature(poFeatureDefn);
+        OGRFeature *poFeature = new OGRFeature(poFeatureDefn);
         poFeature->SetFrom(poSrcFeat);
-        if( bUseSequentialFID )
+        if (bUseSequentialFID)
             poFeature->SetFID(nFeaturesRead);
         else
             poFeature->SetFID(poSrcFeat->GetFID());
         nLastFID = poFeature->GetFID();
-        nFeaturesRead ++;
+        nFeaturesRead++;
         delete poSrcFeat;
 
-        if( (m_poFilterGeom == nullptr
-             || FilterGeometry( poFeature->GetGeometryRef() ) )
-            && (m_poAttrQuery == nullptr
-                || m_poAttrQuery->Evaluate( poFeature )) )
+        if ((m_poFilterGeom == nullptr ||
+             FilterGeometry(poFeature->GetGeometryRef())) &&
+            (m_poAttrQuery == nullptr || m_poAttrQuery->Evaluate(poFeature)))
         {
             return poFeature;
         }
@@ -222,11 +231,11 @@ OGRFeature* OGRESRIFeatureServiceLayer::GetNextFeature()
 /*                          TestCapability()                            */
 /************************************************************************/
 
-int OGRESRIFeatureServiceLayer::TestCapability( const char* pszCap )
+int OGRESRIFeatureServiceLayer::TestCapability(const char *pszCap)
 {
-    if( EQUAL(pszCap, OLCFastFeatureCount) )
+    if (EQUAL(pszCap, OLCFastFeatureCount))
         return m_poAttrQuery == nullptr && m_poFilterGeom == nullptr;
-    if( EQUAL(pszCap, OLCFastGetExtent) )
+    if (EQUAL(pszCap, OLCFastGetExtent))
         return FALSE;
     return poDS->GetUnderlyingLayer()->TestCapability(pszCap);
 }
@@ -235,36 +244,34 @@ int OGRESRIFeatureServiceLayer::TestCapability( const char* pszCap )
 /*                          GetFeatureCount()                           */
 /************************************************************************/
 
-GIntBig OGRESRIFeatureServiceLayer::GetFeatureCount( int bForce )
+GIntBig OGRESRIFeatureServiceLayer::GetFeatureCount(int bForce)
 {
     GIntBig nFeatureCount = -1;
-    if( m_poAttrQuery == nullptr && m_poFilterGeom == nullptr )
+    if (m_poAttrQuery == nullptr && m_poFilterGeom == nullptr)
     {
         CPLString osNewURL =
             CPLURLAddKVP(poDS->GetURL(), "returnCountOnly", "true");
         osNewURL = CPLURLAddKVP(osNewURL, "resultRecordCount", nullptr);
         CPLErrorReset();
-        CPLHTTPResult* pResult = CPLHTTPFetch( osNewURL, nullptr );
-        if( pResult != nullptr &&
-            pResult->nDataLen != 0 &&
-            CPLGetLastErrorNo() == 0 &&
-            pResult->nStatus == 0 )
+        CPLHTTPResult *pResult = CPLHTTPFetch(osNewURL, nullptr);
+        if (pResult != nullptr && pResult->nDataLen != 0 &&
+            CPLGetLastErrorNo() == 0 && pResult->nStatus == 0)
         {
-            const char* pszCount =
-                strstr((const char*)pResult->pabyData, "\"count\"");
-            if( pszCount )
+            const char *pszCount =
+                strstr((const char *)pResult->pabyData, "\"count\"");
+            if (pszCount)
             {
                 pszCount = strchr(pszCount, ':');
-                if( pszCount )
+                if (pszCount)
                 {
                     pszCount++;
                     nFeatureCount = CPLAtoGIntBig(pszCount);
                 }
             }
         }
-        CPLHTTPDestroyResult( pResult );
+        CPLHTTPDestroyResult(pResult);
     }
-    if( nFeatureCount < 0 )
+    if (nFeatureCount < 0)
         nFeatureCount = OGRLayer::GetFeatureCount(bForce);
     return nFeatureCount;
 }
@@ -273,8 +280,7 @@ GIntBig OGRESRIFeatureServiceLayer::GetFeatureCount( int bForce )
 /*                               GetExtent()                            */
 /************************************************************************/
 
-OGRErr OGRESRIFeatureServiceLayer::GetExtent( OGREnvelope *psExtent,
-                                              int bForce )
+OGRErr OGRESRIFeatureServiceLayer::GetExtent(OGREnvelope *psExtent, int bForce)
 {
     OGRErr eErr = OGRERR_FAILURE;
     CPLString osNewURL =
@@ -282,20 +288,20 @@ OGRErr OGRESRIFeatureServiceLayer::GetExtent( OGREnvelope *psExtent,
     osNewURL = CPLURLAddKVP(osNewURL, "resultRecordCount", nullptr);
     osNewURL = CPLURLAddKVP(osNewURL, "f", "geojson");
     CPLErrorReset();
-    CPLHTTPResult* pResult = CPLHTTPFetch( osNewURL, nullptr );
-    if( pResult != nullptr && pResult->nDataLen != 0 && CPLGetLastErrorNo() == 0 &&
-        pResult->nStatus == 0 )
+    CPLHTTPResult *pResult = CPLHTTPFetch(osNewURL, nullptr);
+    if (pResult != nullptr && pResult->nDataLen != 0 &&
+        CPLGetLastErrorNo() == 0 && pResult->nStatus == 0)
     {
-        const char* pszBBox =
-            strstr((const char*)pResult->pabyData, "\"bbox\"");
-        if( pszBBox )
+        const char *pszBBox =
+            strstr((const char *)pResult->pabyData, "\"bbox\"");
+        if (pszBBox)
         {
             pszBBox = strstr(pszBBox, ":[");
-            if( pszBBox )
+            if (pszBBox)
             {
                 pszBBox += 2;
-                char** papszTokens = CSLTokenizeString2(pszBBox, ",", 0);
-                if( CSLCount(papszTokens) >= 4 )
+                char **papszTokens = CSLTokenizeString2(pszBBox, ",", 0);
+                if (CSLCount(papszTokens) >= 4)
                 {
                     psExtent->MinX = CPLAtof(papszTokens[0]);
                     psExtent->MinY = CPLAtof(papszTokens[1]);
@@ -307,8 +313,8 @@ OGRErr OGRESRIFeatureServiceLayer::GetExtent( OGREnvelope *psExtent,
             }
         }
     }
-    CPLHTTPDestroyResult( pResult );
-    if( eErr == OGRERR_FAILURE )
+    CPLHTTPDestroyResult(pResult);
+    if (eErr == OGRERR_FAILURE)
         eErr = OGRLayer::GetExtent(psExtent, bForce);
     return eErr;
 }
@@ -318,30 +324,27 @@ OGRErr OGRESRIFeatureServiceLayer::GetExtent( OGREnvelope *psExtent,
 /************************************************************************/
 
 OGRESRIFeatureServiceDataset::OGRESRIFeatureServiceDataset(
-    const CPLString &osURLIn,
-    OGRGeoJSONDataSource* poFirst) :
-    poCurrent(poFirst)
+    const CPLString &osURLIn, OGRGeoJSONDataSource *poFirst)
+    : poCurrent(poFirst)
 {
     poLayer = new OGRESRIFeatureServiceLayer(this);
     osURL = osURLIn;
-    if( CPLURLGetValue(osURL, "resultRecordCount").empty() )
+    if (CPLURLGetValue(osURL, "resultRecordCount").empty())
     {
         // We assume that if the server sets the exceededTransferLimit, the
         // and resultRecordCount is not set, the number of features returned
         // in our first request is the maximum allowed by the server
         // So set it for following requests.
-        osURL =
-            CPLURLAddKVP(
-                this->osURL, "resultRecordCount",
-                CPLSPrintf(
-                    "%d",
-                    static_cast<int>(poFirst->GetLayer(0)->GetFeatureCount())));
+        osURL = CPLURLAddKVP(
+            this->osURL, "resultRecordCount",
+            CPLSPrintf("%d", static_cast<int>(
+                                 poFirst->GetLayer(0)->GetFeatureCount())));
     }
     else
     {
         const int nUserSetRecordCount =
             atoi(CPLURLGetValue(osURL, "resultRecordCount"));
-        if( nUserSetRecordCount > poFirst->GetLayer(0)->GetFeatureCount() )
+        if (nUserSetRecordCount > poFirst->GetLayer(0)->GetFeatureCount())
         {
             CPLError(CE_Warning, CPLE_AppDefined,
                      "Specified resultRecordCount=%d is greater than "
@@ -370,7 +373,7 @@ OGRESRIFeatureServiceDataset::~OGRESRIFeatureServiceDataset()
 
 int OGRESRIFeatureServiceDataset::MyResetReading()
 {
-    if( nLastOffset > nFirstOffset )
+    if (nLastOffset > nFirstOffset)
     {
         nLastOffset = nFirstOffset;
         return LoadPage();
@@ -386,7 +389,7 @@ int OGRESRIFeatureServiceDataset::MyResetReading()
 
 int OGRESRIFeatureServiceDataset::LoadNextPage()
 {
-    if( !poCurrent->HasOtherPages() )
+    if (!poCurrent->HasOtherPages())
         return FALSE;
     nLastOffset += poCurrent->GetLayer(0)->GetFeatureCount();
     return LoadPage();
@@ -400,16 +403,15 @@ int OGRESRIFeatureServiceDataset::LoadPage()
 {
     CPLString osNewURL = CPLURLAddKVP(osURL, "resultOffset",
                                       CPLSPrintf(CPL_FRMT_GIB, nLastOffset));
-    OGRGeoJSONDataSource* poDS = new OGRGeoJSONDataSource();
+    OGRGeoJSONDataSource *poDS = new OGRGeoJSONDataSource();
     GDALOpenInfo oOpenInfo(osNewURL, GA_ReadOnly);
     GeoJSONSourceType nSrcType;
-    if( EQUAL(poCurrent->GetJSonFlavor(), "GeoJSON") )
-        nSrcType = GeoJSONGetSourceType( &oOpenInfo );
+    if (EQUAL(poCurrent->GetJSonFlavor(), "GeoJSON"))
+        nSrcType = GeoJSONGetSourceType(&oOpenInfo);
     else
-        nSrcType = ESRIJSONDriverGetSourceType( &oOpenInfo );
-    if( !poDS->Open( &oOpenInfo, nSrcType,
-                     poCurrent->GetJSonFlavor() ) ||
-        poDS->GetLayerCount() == 0 )
+        nSrcType = ESRIJSONDriverGetSourceType(&oOpenInfo);
+    if (!poDS->Open(&oOpenInfo, nSrcType, poCurrent->GetJSonFlavor()) ||
+        poDS->GetLayerCount() == 0)
     {
         delete poDS;
         poDS = nullptr;
@@ -424,30 +426,31 @@ int OGRESRIFeatureServiceDataset::LoadPage()
 /*                        OGRGeoJSONDriverIdentify()                    */
 /************************************************************************/
 
-static int OGRGeoJSONDriverIdentifyInternal( GDALOpenInfo* poOpenInfo,
-                                             GeoJSONSourceType& nSrcType )
+static int OGRGeoJSONDriverIdentifyInternal(GDALOpenInfo *poOpenInfo,
+                                            GeoJSONSourceType &nSrcType)
 {
-/* -------------------------------------------------------------------- */
-/*      Determine type of data source: text file (.geojson, .json),     */
-/*      Web Service or text passed directly and load data.              */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Determine type of data source: text file (.geojson, .json),     */
+    /*      Web Service or text passed directly and load data.              */
+    /* -------------------------------------------------------------------- */
 
-    nSrcType = GeoJSONGetSourceType( poOpenInfo );
-    if( nSrcType == eGeoJSONSourceUnknown )
+    nSrcType = GeoJSONGetSourceType(poOpenInfo);
+    if (nSrcType == eGeoJSONSourceUnknown)
         return FALSE;
-    if( nSrcType == eGeoJSONSourceService &&
-        !STARTS_WITH_CI(poOpenInfo->pszFilename, "GeoJSON:") )
+    if (nSrcType == eGeoJSONSourceService &&
+        !STARTS_WITH_CI(poOpenInfo->pszFilename, "GeoJSON:"))
     {
         return -1;
     }
 
     // If this looks like a file that can be handled by the STACTA driver,
     // and that one is available, then don't identify the file.
-    const char* pszHeader = reinterpret_cast<const char*>(poOpenInfo->pabyHeader);
-    if( pszHeader != nullptr &&
+    const char *pszHeader =
+        reinterpret_cast<const char *>(poOpenInfo->pabyHeader);
+    if (pszHeader != nullptr &&
         strstr(pszHeader, "\"stac_extensions\"") != nullptr &&
         strstr(pszHeader, "\"tiled-assets\"") != nullptr &&
-        GDALGetDriverByName("STACTA") != nullptr )
+        GDALGetDriverByName("STACTA") != nullptr)
     {
         return FALSE;
     }
@@ -459,7 +462,7 @@ static int OGRGeoJSONDriverIdentifyInternal( GDALOpenInfo* poOpenInfo,
 /*                        OGRGeoJSONDriverIdentify()                    */
 /************************************************************************/
 
-static int OGRGeoJSONDriverIdentify( GDALOpenInfo* poOpenInfo )
+static int OGRGeoJSONDriverIdentify(GDALOpenInfo *poOpenInfo)
 {
     GeoJSONSourceType nSrcType;
     return OGRGeoJSONDriverIdentifyInternal(poOpenInfo, nSrcType);
@@ -469,10 +472,10 @@ static int OGRGeoJSONDriverIdentify( GDALOpenInfo* poOpenInfo )
 /*                           Open()                                     */
 /************************************************************************/
 
-static GDALDataset* OGRGeoJSONDriverOpen( GDALOpenInfo* poOpenInfo )
+static GDALDataset *OGRGeoJSONDriverOpen(GDALOpenInfo *poOpenInfo)
 {
     GeoJSONSourceType nSrcType;
-    if( OGRGeoJSONDriverIdentifyInternal(poOpenInfo, nSrcType) == FALSE )
+    if (OGRGeoJSONDriverIdentifyInternal(poOpenInfo, nSrcType) == FALSE)
     {
         return nullptr;
     }
@@ -483,58 +486,62 @@ static GDALDataset* OGRGeoJSONDriverOpen( GDALOpenInfo* poOpenInfo )
 /*                     OGRGeoJSONDriverOpenInternal()                   */
 /************************************************************************/
 
-GDALDataset* OGRGeoJSONDriverOpenInternal( GDALOpenInfo* poOpenInfo,
-                                           GeoJSONSourceType nSrcType,
-                                           const char* pszJSonFlavor )
+GDALDataset *OGRGeoJSONDriverOpenInternal(GDALOpenInfo *poOpenInfo,
+                                          GeoJSONSourceType nSrcType,
+                                          const char *pszJSonFlavor)
 {
-    OGRGeoJSONDataSource* poDS = new OGRGeoJSONDataSource();
+    OGRGeoJSONDataSource *poDS = new OGRGeoJSONDataSource();
 
-/* -------------------------------------------------------------------- */
-/*      Processing configuration options.                               */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Processing configuration options.                               */
+    /* -------------------------------------------------------------------- */
 
     // TODO: Currently, options are based on environment variables.
     //       This is workaround for not yet implemented Andrey's concept
     //       described in document 'RFC 10: OGR Open Parameters'.
 
-    poDS->SetGeometryTranslation( OGRGeoJSONDataSource::eGeometryPreserve );
-    const char* pszOpt = CPLGetConfigOption("GEOMETRY_AS_COLLECTION", nullptr);
-    if( nullptr != pszOpt && STARTS_WITH_CI(pszOpt, "YES") )
+    poDS->SetGeometryTranslation(OGRGeoJSONDataSource::eGeometryPreserve);
+    const char *pszOpt = CPLGetConfigOption("GEOMETRY_AS_COLLECTION", nullptr);
+    if (nullptr != pszOpt && STARTS_WITH_CI(pszOpt, "YES"))
     {
         poDS->SetGeometryTranslation(
-            OGRGeoJSONDataSource::eGeometryAsCollection );
+            OGRGeoJSONDataSource::eGeometryAsCollection);
     }
 
-    poDS->SetAttributesTranslation( OGRGeoJSONDataSource::eAttributesPreserve );
+    poDS->SetAttributesTranslation(OGRGeoJSONDataSource::eAttributesPreserve);
     pszOpt = CPLGetConfigOption("ATTRIBUTES_SKIP", nullptr);
-    if( nullptr != pszOpt && STARTS_WITH_CI(pszOpt, "YES") )
+    if (nullptr != pszOpt && STARTS_WITH_CI(pszOpt, "YES"))
     {
-        poDS->SetAttributesTranslation(
-            OGRGeoJSONDataSource::eAttributesSkip );
+        poDS->SetAttributesTranslation(OGRGeoJSONDataSource::eAttributesSkip);
     }
 
-/* -------------------------------------------------------------------- */
-/*      Open and start processing GeoJSON datasource to OGR objects.    */
-/* -------------------------------------------------------------------- */
-    if( !poDS->Open( poOpenInfo, nSrcType, pszJSonFlavor ) )
+    /* -------------------------------------------------------------------- */
+    /*      Open and start processing GeoJSON datasource to OGR objects.    */
+    /* -------------------------------------------------------------------- */
+    if (!poDS->Open(poOpenInfo, nSrcType, pszJSonFlavor))
     {
         delete poDS;
         poDS = nullptr;
     }
 
-    if( poDS != nullptr && poDS->HasOtherPages() &&
-        (STARTS_WITH(poOpenInfo->pszFilename, "http") ||
-         STARTS_WITH(poOpenInfo->pszFilename, "/vsimem/")) )
+    if (poDS != nullptr && poDS->HasOtherPages())
     {
-        const char* pszFSP = CSLFetchNameValue(poOpenInfo->papszOpenOptions,
-                                               "FEATURE_SERVER_PAGING");
-        const bool bHasResultOffset =
-          !CPLURLGetValue(poOpenInfo->pszFilename, "resultOffset").empty();
-        if( (!bHasResultOffset && (pszFSP == nullptr || CPLTestBool(pszFSP))) ||
-            (bHasResultOffset && pszFSP != nullptr && CPLTestBool(pszFSP)) )
+        const char *pszFilename = poOpenInfo->pszFilename;
+        if (STARTS_WITH_CI(pszFilename, "ESRIJSON:"))
+            pszFilename += strlen("ESRIJSON:");
+        if (STARTS_WITH(pszFilename, "http") ||
+            STARTS_WITH(pszFilename, "/vsimem/"))
         {
-            return new OGRESRIFeatureServiceDataset(poOpenInfo->pszFilename,
-                                                    poDS);
+            const char *pszFSP = CSLFetchNameValue(poOpenInfo->papszOpenOptions,
+                                                   "FEATURE_SERVER_PAGING");
+            const bool bHasResultOffset =
+                !CPLURLGetValue(pszFilename, "resultOffset").empty();
+            if ((!bHasResultOffset &&
+                 (pszFSP == nullptr || CPLTestBool(pszFSP))) ||
+                (bHasResultOffset && pszFSP != nullptr && CPLTestBool(pszFSP)))
+            {
+                return new OGRESRIFeatureServiceDataset(pszFilename, poDS);
+            }
         }
     }
 
@@ -545,16 +552,15 @@ GDALDataset* OGRGeoJSONDriverOpenInternal( GDALOpenInfo* poOpenInfo,
 /*                               Create()                               */
 /************************************************************************/
 
-static GDALDataset *OGRGeoJSONDriverCreate( const char * pszName,
-                                            int /* nBands */,
-                                            int /* nXSize */,
-                                            int /* nYSize */,
-                                            GDALDataType /* eDT */,
-                                            char **papszOptions )
+static GDALDataset *OGRGeoJSONDriverCreate(const char *pszName,
+                                           int /* nBands */, int /* nXSize */,
+                                           int /* nYSize */,
+                                           GDALDataType /* eDT */,
+                                           char **papszOptions)
 {
-    OGRGeoJSONDataSource* poDS = new OGRGeoJSONDataSource();
+    OGRGeoJSONDataSource *poDS = new OGRGeoJSONDataSource();
 
-    if( !poDS->Create( pszName, papszOptions ) )
+    if (!poDS->Create(pszName, papszOptions))
     {
         delete poDS;
         poDS = nullptr;
@@ -567,14 +573,14 @@ static GDALDataset *OGRGeoJSONDriverCreate( const char * pszName,
 /*                               Delete()                               */
 /************************************************************************/
 
-static CPLErr OGRGeoJSONDriverDelete( const char *pszFilename )
+static CPLErr OGRGeoJSONDriverDelete(const char *pszFilename)
 {
-    if( VSIUnlink( pszFilename ) == 0 )
+    if (VSIUnlink(pszFilename) == 0)
     {
         return CE_None;
     }
 
-    CPLDebug( "GeoJSON", "Failed to delete \'%s\'", pszFilename);
+    CPLDebug("GeoJSON", "Failed to delete \'%s\'", pszFilename);
 
     return CE_Failure;
 }
@@ -583,11 +589,11 @@ static CPLErr OGRGeoJSONDriverDelete( const char *pszFilename )
 /*                      OGRGeoJSONDriverStoreContent()                  */
 /************************************************************************/
 
-void OGRGeoJSONDriverStoreContent( const char* pszSource, char* pszText )
+void OGRGeoJSONDriverStoreContent(const char *pszSource, char *pszText)
 {
     CPLMutexHolderD(&ghMutex);
-    CPLAssert( pszSource );
-    CPLAssert( pszText );
+    CPLAssert(pszSource);
+    CPLAssert(pszText);
 
     CPLFree(gpszSource);
     CPLFree(gpszText);
@@ -599,12 +605,12 @@ void OGRGeoJSONDriverStoreContent( const char* pszSource, char* pszText )
 /*                    OGRGeoJSONDriverStealStoredContent()              */
 /************************************************************************/
 
-char* OGRGeoJSONDriverStealStoredContent( const char* pszSource )
+char *OGRGeoJSONDriverStealStoredContent(const char *pszSource)
 {
     CPLMutexHolderD(&ghMutex);
-    if( gpszSource && EQUAL(pszSource, gpszSource) )
+    if (gpszSource && EQUAL(pszSource, gpszSource))
     {
-        char* pszRet = gpszText;
+        char *pszRet = gpszText;
         CPLFree(gpszSource);
         gpszSource = nullptr;
         gpszText = nullptr;
@@ -617,9 +623,9 @@ char* OGRGeoJSONDriverStealStoredContent( const char* pszSource )
 /*                        OGRGeoJSONDriverUnload()                      */
 /************************************************************************/
 
-static void OGRGeoJSONDriverUnload( GDALDriver* )
+static void OGRGeoJSONDriverUnload(GDALDriver *)
 {
-    if( ghMutex )
+    if (ghMutex)
         CPLDestroyMutex(ghMutex);
     ghMutex = nullptr;
     CPLFree(gpszSource);
@@ -634,58 +640,99 @@ static void OGRGeoJSONDriverUnload( GDALDriver* )
 
 void RegisterOGRGeoJSON()
 {
-    if( !GDAL_CHECK_VERSION("OGR/GeoJSON driver") )
+    if (!GDAL_CHECK_VERSION("OGR/GeoJSON driver"))
         return;
 
-    if( GDALGetDriverByName( "GeoJSON" ) != nullptr )
+    if (GDALGetDriverByName("GeoJSON") != nullptr)
         return;
 
     GDALDriver *poDriver = new GDALDriver();
 
-    poDriver->SetDescription( "GeoJSON" );
-    poDriver->SetMetadataItem( GDAL_DCAP_VECTOR, "YES" );
-    poDriver->SetMetadataItem( GDAL_DMD_LONGNAME, "GeoJSON" );
-    poDriver->SetMetadataItem( GDAL_DMD_EXTENSIONS, "json geojson" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/vector/geojson.html" );
+    poDriver->SetDescription("GeoJSON");
+    poDriver->SetMetadataItem(GDAL_DCAP_VECTOR, "YES");
+    poDriver->SetMetadataItem(GDAL_DCAP_CREATE_LAYER, "YES");
+    poDriver->SetMetadataItem(GDAL_DCAP_CREATE_FIELD, "YES");
+    poDriver->SetMetadataItem(GDAL_DCAP_Z_GEOMETRIES, "YES");
+    poDriver->SetMetadataItem(GDAL_DMD_LONGNAME, "GeoJSON");
+    poDriver->SetMetadataItem(GDAL_DMD_EXTENSIONS, "json geojson");
+    poDriver->SetMetadataItem(GDAL_DMD_HELPTOPIC,
+                              "drivers/vector/geojson.html");
 
-    poDriver->SetMetadataItem( GDAL_DMD_OPENOPTIONLIST,
-"<OpenOptionList>"
-"  <Option name='FLATTEN_NESTED_ATTRIBUTES' type='boolean' description='Whether to recursively explore nested objects and produce flatten OGR attributes' default='NO'/>"
-"  <Option name='NESTED_ATTRIBUTE_SEPARATOR' type='string' description='Separator between components of nested attributes' default='_'/>"
-"  <Option name='FEATURE_SERVER_PAGING' type='boolean' description='Whether to automatically scroll through results with a ArcGIS Feature Service endpoint'/>"
-"  <Option name='NATIVE_DATA' type='boolean' description='Whether to store the native JSon representation at FeatureCollection and Feature level' default='NO'/>"
-"  <Option name='ARRAY_AS_STRING' type='boolean' description='Whether to expose JSon arrays of strings, integers or reals as a OGR String' default='NO'/>"
-"  <Option name='DATE_AS_STRING' type='boolean' description='Whether to expose date/time/date-time content using dedicated OGR date/time/date-time types or as a OGR String' default='NO'/>"
-"</OpenOptionList>");
+    poDriver->SetMetadataItem(
+        GDAL_DMD_OPENOPTIONLIST,
+        "<OpenOptionList>"
+        "  <Option name='FLATTEN_NESTED_ATTRIBUTES' type='boolean' "
+        "description='Whether to recursively explore nested objects and "
+        "produce flatten OGR attributes' default='NO'/>"
+        "  <Option name='NESTED_ATTRIBUTE_SEPARATOR' type='string' "
+        "description='Separator between components of nested attributes' "
+        "default='_'/>"
+        "  <Option name='FEATURE_SERVER_PAGING' type='boolean' "
+        "description='Whether to automatically scroll through results with a "
+        "ArcGIS Feature Service endpoint'/>"
+        "  <Option name='NATIVE_DATA' type='boolean' description='Whether to "
+        "store the native JSon representation at FeatureCollection and Feature "
+        "level' default='NO'/>"
+        "  <Option name='ARRAY_AS_STRING' type='boolean' description='Whether "
+        "to expose JSon arrays of strings, integers or reals as a OGR String' "
+        "default='NO'/>"
+        "  <Option name='DATE_AS_STRING' type='boolean' description='Whether "
+        "to expose date/time/date-time content using dedicated OGR "
+        "date/time/date-time types or as a OGR String' default='NO'/>"
+        "</OpenOptionList>");
 
-    poDriver->SetMetadataItem( GDAL_DMD_CREATIONOPTIONLIST,
-                               "<CreationOptionList/>");
+    poDriver->SetMetadataItem(GDAL_DMD_CREATIONOPTIONLIST,
+                              "<CreationOptionList/>");
 
-    poDriver->SetMetadataItem( GDAL_DS_LAYER_CREATIONOPTIONLIST,
-"<LayerCreationOptionList>"
-"  <Option name='WRITE_BBOX' type='boolean' description='whether to write a bbox property with the bounding box of the geometries at the feature and feature collection level' default='NO'/>"
-"  <Option name='COORDINATE_PRECISION' type='int' description='Number of decimal for coordinates. Default is 15 for GJ2008 and 7 for RFC7946'/>"
-"  <Option name='SIGNIFICANT_FIGURES' type='int' description='Number of significant figures for floating-point values' default='17'/>"
-"  <Option name='NATIVE_DATA' type='string' description='FeatureCollection level elements.'/>"
-"  <Option name='NATIVE_MEDIA_TYPE' type='string' description='Format of NATIVE_DATA. Must be \"application/vnd.geo+json\", otherwise NATIVE_DATA will be ignored.'/>"
-"  <Option name='RFC7946' type='boolean' description='Whether to use RFC 7946 standard. Otherwise GeoJSON 2008 initial version will be used' default='NO'/>"
-"  <Option name='WRITE_NAME' type='boolean' description='Whether to write a &quot;name&quot; property at feature collection level with layer name' default='YES'/>"
-"  <Option name='DESCRIPTION' type='string' description='(Long) description to write in a &quot;description&quot; property at feature collection level'/>"
-"  <Option name='ID_FIELD' type='string' description='Name of the source field that must be used as the id member of Feature features'/>"
-"  <Option name='ID_TYPE' type='string-select' description='Type of the id member of Feature features'>"
-"    <Value>AUTO</Value>"
-"    <Value>String</Value>"
-"    <Value>Integer</Value>"
-"  </Option>"
-"  <Option name='ID_GENERATE' type='boolean' description='Auto-generate feature ids' />"
-"  <Option name='WRITE_NON_FINITE_VALUES' type='boolean' description='Whether to write NaN / Infinity values' default='NO'/>"
-"</LayerCreationOptionList>");
+    poDriver->SetMetadataItem(
+        GDAL_DS_LAYER_CREATIONOPTIONLIST,
+        "<LayerCreationOptionList>"
+        "  <Option name='WRITE_BBOX' type='boolean' description='whether to "
+        "write a bbox property with the bounding box of the geometries at the "
+        "feature and feature collection level' default='NO'/>"
+        "  <Option name='COORDINATE_PRECISION' type='int' description='Number "
+        "of decimal for coordinates. Default is 15 for GJ2008 and 7 for "
+        "RFC7946'/>"
+        "  <Option name='SIGNIFICANT_FIGURES' type='int' description='Number "
+        "of significant figures for floating-point values' default='17'/>"
+        "  <Option name='NATIVE_DATA' type='string' "
+        "description='FeatureCollection level elements.'/>"
+        "  <Option name='NATIVE_MEDIA_TYPE' type='string' description='Format "
+        "of NATIVE_DATA. Must be \"application/vnd.geo+json\", otherwise "
+        "NATIVE_DATA will be ignored.'/>"
+        "  <Option name='RFC7946' type='boolean' description='Whether to use "
+        "RFC 7946 standard. Otherwise GeoJSON 2008 initial version will be "
+        "used' default='NO'/>"
+        "  <Option name='WRAPDATELINE' type='boolean' description='Whether to "
+        "apply heuristics to split geometries that cross dateline.' "
+        "default='YES'/>"
+        "  <Option name='WRITE_NAME' type='boolean' description='Whether to "
+        "write a &quot;name&quot; property at feature collection level with "
+        "layer name' default='YES'/>"
+        "  <Option name='DESCRIPTION' type='string' description='(Long) "
+        "description to write in a &quot;description&quot; property at feature "
+        "collection level'/>"
+        "  <Option name='ID_FIELD' type='string' description='Name of the "
+        "source field that must be used as the id member of Feature features'/>"
+        "  <Option name='ID_TYPE' type='string-select' description='Type of "
+        "the id member of Feature features'>"
+        "    <Value>AUTO</Value>"
+        "    <Value>String</Value>"
+        "    <Value>Integer</Value>"
+        "  </Option>"
+        "  <Option name='ID_GENERATE' type='boolean' "
+        "description='Auto-generate feature ids' />"
+        "  <Option name='WRITE_NON_FINITE_VALUES' type='boolean' "
+        "description='Whether to write NaN / Infinity values' default='NO'/>"
+        "</LayerCreationOptionList>");
 
-    poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
-    poDriver->SetMetadataItem( GDAL_DMD_CREATIONFIELDDATATYPES,
-                               "Integer Integer64 Real String IntegerList "
-                               "Integer64List RealList StringList Date DateTime" );
-    poDriver->SetMetadataItem( GDAL_DMD_CREATIONFIELDDATASUBTYPES, "Boolean" );
+    poDriver->SetMetadataItem(GDAL_DCAP_VIRTUALIO, "YES");
+    poDriver->SetMetadataItem(
+        GDAL_DMD_CREATIONFIELDDATATYPES,
+        "Integer Integer64 Real String IntegerList "
+        "Integer64List RealList StringList Date DateTime");
+    poDriver->SetMetadataItem(GDAL_DMD_CREATIONFIELDDATASUBTYPES, "Boolean");
+    poDriver->SetMetadataItem(GDAL_DMD_SUPPORTED_SQL_DIALECTS, "OGRSQL SQLITE");
 
     poDriver->pfnOpen = OGRGeoJSONDriverOpen;
     poDriver->pfnIdentify = OGRGeoJSONDriverIdentify;
@@ -693,5 +740,5 @@ void RegisterOGRGeoJSON()
     poDriver->pfnDelete = OGRGeoJSONDriverDelete;
     poDriver->pfnUnloadDriver = OGRGeoJSONDriverUnload;
 
-    GetGDALDriverManager()->RegisterDriver( poDriver );
+    GetGDALDriverManager()->RegisterDriver(poDriver);
 }
